CleanMerge.sps
Syntax for creating a CLEAN datafile for Scenes project analysis
Started 9/2/2008
Eric Rogers (ericrogers@gmail.com)


**We're using the old Merge3 as our "clean" data file.  Merge3 has 343 variables and 42,192 cases.  
The number of cases should not change in the following steps.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/Old Merges/merge3.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

SORT CASES BY countcen(A).

*Now saving it as a new file, to start the new CLEAN merge sequence.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-1.sav'
  /COMPRESSED.

*Sorted by countcen for merges, and it has the right number of cases still.


******************************************

**Now, merging in the DDB performance scores.

*First, opening the file that was used to merge it in last time (since we know that worked).  See line 1012 of EARSyntax1.sps for context.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/DDB-PerformanceScores/ddb-county-scores.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

*Sorting it by countcen.

SORT CASES BY countcen(A).

*And now to run the merge!  Note that MergeB-1 is active, and the DDB file is DataSet2.

MATCH FILES /FILE=*
  /TABLE='DataSet2'
  /BY  countcen.
EXECUTE.

*Looks good.  Variables added, case count still 42192, N's good.  Saving as the next in the new sequence.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-2.sav'
  /COMPRESSED.

**Now need to create the factor index.  
*Step 1:  save z-scores for the dimensions.

DESCRIPTIVES VARIABLES=SpxMTtrad22nn_mean SpxMTse22nn_mean SpxMTegal22nn_mean SpxMTutil22nn_mean 
    SpxMTchar22nn_mean SpxMTneigh22nn_mean SpxMTform22nn_mean SpxMTexhib22nn_mean SpxMTglam22nn_mean 
    SpxMTtrans22nn_mean SpxMTratio22nn_mean SpxMTlocal22nn_mean SpxMTstate22nn_mean SpxMTcorpo22nn_mean
  /SAVE
  /STATISTICS=MEAN STDDEV MIN MAX.

**N's the same, so this should be good.  Saving.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-2.sav'
  /COMPRESSED.

*Now, need to run the factor analysis and save the factor scores.  I think this should do it:

FACTOR
  /VARIABLES ZSpxMTtrad22nn_mean ZSpxMTse22nn_mean ZSpxMTegal22nn_mean ZSpxMTutil22nn_mean 
    ZSpxMTchar22nn_mean ZSpxMTneigh22nn_mean ZSpxMTform22nn_mean ZSpxMTexhib22nn_mean 
    ZSpxMTglam22nn_mean ZSpxMTtrans22nn_mean ZSpxMTratio22nn_mean ZSpxMTlocal22nn_mean 
    ZSpxMTstate22nn_mean ZSpxMTcorpo22nn_mean
  /MISSING LISTWISE 
  /ANALYSIS ZSpxMTtrad22nn_mean ZSpxMTse22nn_mean ZSpxMTegal22nn_mean ZSpxMTutil22nn_mean 
    ZSpxMTchar22nn_mean ZSpxMTneigh22nn_mean ZSpxMTform22nn_mean ZSpxMTexhib22nn_mean 
    ZSpxMTglam22nn_mean ZSpxMTtrans22nn_mean ZSpxMTratio22nn_mean ZSpxMTlocal22nn_mean 
    ZSpxMTstate22nn_mean ZSpxMTcorpo22nn_mean
  /PRINT UNIVARIATE INITIAL EXTRACTION FSCORE
  /CRITERIA FACTORS(1) ITERATE(25)
  /EXTRACTION PC
  /ROTATION NOROTATE
  /SAVE REG(ALL)
  /METHOD=CORRELATION.

*As far as I can tell, this is what we need, and the N is good, so I'm manually giving the variable the name "DDBfactor1" as well as a description.

*Then saving.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-2.sav'
  /COMPRESSED.

*9/23
Need to delete the Z-scores and the factor scores computed above, as they need to be re-done with imputed values for the missing cases.
Did by hand, now saving...

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-2.sav'
  /COMPRESSED.

*After deleting, moving on to merging in the bizzip and YP data...
*Per Chris recommendation, want to merge together his bizzip and YP scores into one common file, and THEN merge that in with the main file.

*First step of this is to merge the county-level BZ and YP files together, as they're both keyed to FIPS.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CMG Performance Scores/GraziulScenes.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.


SORT CASES BY FIPS(A).

*No change, so not saving this one.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CMG Performance Scores/YPperfCounty.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

SORT CASES BY FIPS(A).

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CMG Performance Scores/YPperfCounty.sav'
  /COMPRESSED.

*OK, these two are sorted by FIPS, and ready to merge.  Want to merge such that both files contribute cases. 
*The files in referenced in the syntax below are the ones opened above.

MATCH FILES /FILE=*
  /RENAME (esNAICS_EXT = d0) 
  /FILE='DataSet1'
  /RENAME (esNAICS_EXT = d1)
  /BY  FIPS
  /DROP= d0 d1.
EXECUTE.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CMG Performance Scores/CMGCountyScoresBZ-YP.sav'
  /COMPRESSED.

*Variables all there as expected, looks good visually, and the case counts and Ns are good.
*Manually appending _cty to all the county-level versions, and applying labels that identify them appropriately.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CMG Performance Scores/CMGCountyScoresBZ-YP.sav'
  /COMPRESSED.


*NOW to merge in the zip-level data.  Opening the mergefile first...

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-2.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

SORT CASES BY zipcode(A).

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-2.sav'
  /COMPRESSED.

*Now opening the zip-level file with the performance scores...

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CMG Performance Scores/CMGPerfScoresBZ-YP.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

SORT CASES BY zipcode(A).

*Making MergeB-2 the active dataset (*), and then a merge with just MergeB-2 contributing cases...

MATCH FILES /FILE=*
  /TABLE='DataSet2'
  /BY  zipcode.
EXECUTE.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-3.sav'
  /COMPRESSED.


***Now, to merge in the county data.  First, opening the main file and sorting it on countcen...

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-3.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

SORT CASES BY countcen(A).

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-3.sav'
  /COMPRESSED.

*Now, opening the county file from Chris...

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CMG Performance Scores/CMGCountyScoresBZ-YP.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

*Changing "FIPS" to "countcen" manually, sorting on it, then saving again.

SORT CASES BY countcen(A).

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CMG Performance Scores/CMGCountyScoresBZ-YP.sav'
  /COMPRESSED.

*Now making the main merge file active, and initiating a merge with Chris' file as the keyed table...

MATCH FILES /FILE=*
  /TABLE='DataSet2'
  /BY  countcen.
EXECUTE.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-4.sav'
  /COMPRESSED.

*Looks good!

*Now, moving on to imputing for missing cases for all three source of performance scores.  Developing the syntax for this in Excel, then pasting here.

compute SpxMTtrad22nn_mean_impu=SpxMTtrad22nn_mean.
compute SpxMTse22nn_mean_impu=SpxMTse22nn_mean.
compute SpxMTegal22nn_mean_impu=SpxMTegal22nn_mean.
compute SpxMTutil22nn_mean_impu=SpxMTutil22nn_mean.
compute SpxMTchar22nn_mean_impu=SpxMTchar22nn_mean.
compute SpxMTneigh22nn_mean_impu=SpxMTneigh22nn_mean.
compute SpxMTform22nn_mean_impu=SpxMTform22nn_mean.
compute SpxMTexhib22nn_mean_impu=SpxMTexhib22nn_mean.
compute SpxMTglam22nn_mean_impu=SpxMTglam22nn_mean.
compute SpxMTtrans22nn_mean_impu=SpxMTtrans22nn_mean.
compute SpxMTratio22nn_mean_impu=SpxMTratio22nn_mean.
compute SpxMTlocal22nn_mean_impu=SpxMTlocal22nn_mean.
compute SpxMTstate22nn_mean_impu=SpxMTstate22nn_mean.
compute SpxMTcorpo22nn_mean_impu=SpxMTcorpo22nn_mean.
compute BZ01TradPerf_impu=BZ01TradPerf.
compute BZ01SEPerf_impu=BZ01SEPerf.
compute BZ01UtilPerf_impu=BZ01UtilPerf.
compute BZ01CharPerf_impu=BZ01CharPerf.
compute BZ01EgalPerf_impu=BZ01EgalPerf.
compute BZ01NeighPerf_impu=BZ01NeighPerf.
compute BZ01FormPerf_impu=BZ01FormPerf.
compute BZ01ExhiPerf_impu=BZ01ExhiPerf.
compute BZ01GlamPerf_impu=BZ01GlamPerf.
compute BZ01TransPerf_impu=BZ01TransPerf.
compute BZ01RatPerf_impu=BZ01RatPerf.
compute BZ01LocalPerf_impu=BZ01LocalPerf.
compute BZ01StatePerf_impu=BZ01StatePerf.
compute BZ01CorpPerf_impu=BZ01CorpPerf.
compute BZ01EthnPerf_impu=BZ01EthnPerf.
compute YPTradPerf_impu=YPTradPerf.
compute YPSEPerf_impu=YPSEPerf.
compute YPUtilPerf_impu=YPUtilPerf.
compute YPCharPerf_impu=YPCharPerf.
compute YPEgalPerf_impu=YPEgalPerf.
compute YPNeighPerf_impu=YPNeighPerf.
compute YPFormPerf_impu=YPFormPerf.
compute YPExhiPerf_impu=YPExhiPerf.
compute YPGlamPerf_impu=YPGlamPerf.
compute YPTransPerf_impu=YPTransPerf.
compute YPRatPerf_impu=YPRatPerf.
compute YPLocalPerf_impu=YPLocalPerf.
compute YPStatePerf_impu=YPStatePerf.
compute YPCorpPerf_impu=YPCorpPerf.
compute YPEthnPerf_impu=YPEthnPerf.
execute.

*Saving and restarting, as SPSS has become balky.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-4.sav'
  /COMPRESSED.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-4.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

*Now, to apply some labels to these things.  Should also be simple using Excel to create syntax that adapts from the existing labels.
*Just add "(i2.99)" to the labels.

var lab			
SpxMTtrad22nn_mean_impu 'DDB traditionalism index, county (i0)'
SpxMTse22nn_mean_impu 'DDB self-expression index, county (i0)'
SpxMTegal22nn_mean_impu 'DDB egalitarianism index, county (i0)'
SpxMTutil22nn_mean_impu 'DDB utilitarianism index, county (i0)'
SpxMTchar22nn_mean_impu 'DDB charismatic index, county (i0)'
SpxMTneigh22nn_mean_impu 'DDB neighborliness index, county (i0)'
SpxMTform22nn_mean_impu 'DDB formality index, county (i0)'
SpxMTexhib22nn_mean_impu 'DDB exhibitionism index, county (i0)'
SpxMTglam22nn_mean_impu 'DDB glamour index, county (i0)'
SpxMTtrans22nn_mean_impu 'DDB transgressive index, county (i0)'
SpxMTratio22nn_mean_impu 'DDB rational index, county (i0)'
SpxMTlocal22nn_mean_impu 'DDB localism index, county (i0)'
SpxMTstate22nn_mean_impu 'DDB statism index, county (i0)'
SpxMTcorpo22nn_mean_impu 'DDB corporatism index, county (i0)'
BZ01TradPerf_impu 'Traditionalism performance score from 2001 Bizzip data (i2.99)'
BZ01SEPerf_impu 'Self-Expression performance score from 2001 Bizzip data (i2.99)'
BZ01UtilPerf_impu 'Utilitarianism performance score from 2001 Bizzip data (i2.99)'
BZ01CharPerf_impu 'Charismatic performance score from 2001 Bizzip data (i2.99)'
BZ01EgalPerf_impu 'Egalitarian performance score from 2001 Bizzip data (i2.99)'
BZ01NeighPerf_impu 'Neighborliness performance score from 2001 Bizzip data (i2.99)'
BZ01FormPerf_impu 'Formality performance score from 2001 Bizzip data (i2.99)'
BZ01ExhiPerf_impu 'Exhibitionism performance score from 2001 Bizzip data (i2.99)'
BZ01GlamPerf_impu 'Glamour performance score from 2001 Bizzip data (i2.99)'
BZ01TransPerf_impu 'Transgressive performance score from 2001 Bizzip data (i2.99)'
BZ01RatPerf_impu 'Rational performance score from 2001 Bizzip data (i2.99)'
BZ01LocalPerf_impu 'Localism performance score from 2001 Bizzip data (i2.99)'
BZ01StatePerf_impu 'Statism performance score from 2001 Bizzip data (i2.99)'
BZ01CorpPerf_impu 'Corporatism performance score from 2001 Bizzip data (i2.99)'
BZ01EthnPerf_impu 'Ethnicity performance score from 2001 Bizzip data (i2.99)'
YPTradPerf_impu 'Traditionalism performance score from Yellow Pages data (i2.99)'
YPSEPerf_impu 'Self-Expression performance score from Yellow Pages data (i2.99)'
YPUtilPerf_impu 'Utilitarianism performance score from Yellow Pages data (i2.99)'
YPCharPerf_impu 'Charismatic performance score from Yellow Pages data (i2.99)'
YPEgalPerf_impu 'Egalitarian performance score from Yellow Pages data (i2.99)'
YPNeighPerf_impu 'Neighborliness performance score from Yellow Pages data (i2.99)'
YPFormPerf_impu 'Formality performance score from Yellow Pages data (i2.99)'
YPExhiPerf_impu 'Exhibitionism performance score from Yellow Pages data (i2.99)'
YPGlamPerf_impu 'Glamour performance score from Yellow Pages data (i2.99)'
YPTransPerf_impu 'Transgressive performance score from Yellow Pages data (i2.99)'
YPRatPerf_impu 'Rational performance score from Yellow Pages data (i2.99)'
YPLocalPerf_impu 'Localism performance score from Yellow Pages data (i2.99)'
YPStatePerf_impu 'Statism performance score from Yellow Pages data (i2.99)'
YPCorpPerf_impu 'Corporatism performance score from Yellow Pages data (i2.99)'
YPEthnPerf_impu 'Ethnicity performance score from Yellow Pages data (i2.99)'.

*Great, this worked, now saving and restarting for same reason as before: SPSS becomes balky after pasting from Excel.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-4.sav'
  /COMPRESSED.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-4.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

**Now, to do the actual recode for imputation:

recode SpxMTtrad22nn_mean_impu to SpxMTcorpo22nn_mean_impu (sysmis=0).
recode BZ01TradPerf_impu to YPEthnPerf_impu (sysmis=2.99).
execute.

*save with a slightly different filename, just in case!

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-4i.sav'
  /COMPRESSED.

**Next, need to do the factor scores.  Reopening file:

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-4i.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

*The first step is to create z-scores for every dimension.  Just run descriptives and save standardized versions.

DESCRIPTIVES VARIABLES=SpxMTtrad22nn_mean_impu SpxMTse22nn_mean_impu SpxMTegal22nn_mean_impu 
    SpxMTutil22nn_mean_impu SpxMTchar22nn_mean_impu SpxMTneigh22nn_mean_impu SpxMTform22nn_mean_impu 
    SpxMTexhib22nn_mean_impu SpxMTglam22nn_mean_impu SpxMTtrans22nn_mean_impu SpxMTratio22nn_mean_impu 
    SpxMTlocal22nn_mean_impu SpxMTstate22nn_mean_impu SpxMTcorpo22nn_mean_impu BZ01TradPerf_impu 
    BZ01SEPerf_impu BZ01UtilPerf_impu BZ01CharPerf_impu BZ01EgalPerf_impu BZ01NeighPerf_impu 
    BZ01FormPerf_impu BZ01ExhiPerf_impu BZ01GlamPerf_impu BZ01TransPerf_impu BZ01RatPerf_impu 
    BZ01LocalPerf_impu BZ01StatePerf_impu BZ01CorpPerf_impu BZ01EthnPerf_impu YPTradPerf_impu 
    YPSEPerf_impu YPUtilPerf_impu YPCharPerf_impu YPEgalPerf_impu YPNeighPerf_impu YPFormPerf_impu 
    YPExhiPerf_impu YPGlamPerf_impu YPTransPerf_impu YPRatPerf_impu YPLocalPerf_impu YPStatePerf_impu 
    YPCorpPerf_impu YPEthnPerf_impu
  /SAVE
  /STATISTICS=MEAN STDDEV MIN MAX.

*OK, this is done, now need to run and save the factor score.
*First, for the DDB dimensions:

FACTOR
  /VARIABLES ZSpxMTtrad22nn_mean_impu ZSpxMTse22nn_mean_impu ZSpxMTegal22nn_mean_impu 
    ZSpxMTutil22nn_mean_impu ZSpxMTchar22nn_mean_impu ZSpxMTneigh22nn_mean_impu 
    ZSpxMTform22nn_mean_impu ZSpxMTexhib22nn_mean_impu ZSpxMTglam22nn_mean_impu 
    ZSpxMTtrans22nn_mean_impu ZSpxMTratio22nn_mean_impu ZSpxMTlocal22nn_mean_impu 
    ZSpxMTstate22nn_mean_impu ZSpxMTcorpo22nn_mean_impu
  /MISSING LISTWISE 
  /ANALYSIS ZSpxMTtrad22nn_mean_impu ZSpxMTse22nn_mean_impu ZSpxMTegal22nn_mean_impu 
    ZSpxMTutil22nn_mean_impu ZSpxMTchar22nn_mean_impu ZSpxMTneigh22nn_mean_impu 
    ZSpxMTform22nn_mean_impu ZSpxMTexhib22nn_mean_impu ZSpxMTglam22nn_mean_impu 
    ZSpxMTtrans22nn_mean_impu ZSpxMTratio22nn_mean_impu ZSpxMTlocal22nn_mean_impu 
    ZSpxMTstate22nn_mean_impu ZSpxMTcorpo22nn_mean_impu
  /PRINT UNIVARIATE INITIAL EXTRACTION FSCORE
  /CRITERIA FACTORS(1) ITERATE(25)
  /EXTRACTION PC
  /ROTATION NOROTATE
  /SAVE REG(ALL)
  /METHOD=CORRELATION.

*Renaming this new variable to "DDB_FactorScore" by hand.
*Now, running for bizzip:

FACTOR
  /VARIABLES ZBZ01TradPerf_impu ZBZ01SEPerf_impu ZBZ01UtilPerf_impu ZBZ01CharPerf_impu 
    ZBZ01EgalPerf_impu ZBZ01NeighPerf_impu ZBZ01FormPerf_impu ZBZ01ExhiPerf_impu ZBZ01GlamPerf_impu 
    ZBZ01TransPerf_impu ZBZ01RatPerf_impu ZBZ01LocalPerf_impu ZBZ01StatePerf_impu ZBZ01CorpPerf_impu 
    ZBZ01EthnPerf_impu
  /MISSING LISTWISE 
  /ANALYSIS ZBZ01TradPerf_impu ZBZ01SEPerf_impu ZBZ01UtilPerf_impu ZBZ01CharPerf_impu 
    ZBZ01EgalPerf_impu ZBZ01NeighPerf_impu ZBZ01FormPerf_impu ZBZ01ExhiPerf_impu ZBZ01GlamPerf_impu 
    ZBZ01TransPerf_impu ZBZ01RatPerf_impu ZBZ01LocalPerf_impu ZBZ01StatePerf_impu ZBZ01CorpPerf_impu 
    ZBZ01EthnPerf_impu
  /PRINT UNIVARIATE INITIAL EXTRACTION FSCORE
  /CRITERIA FACTORS(1) ITERATE(25)
  /EXTRACTION PC
  /ROTATION NOROTATE
  /SAVE REG(ALL)
  /METHOD=CORRELATION.

*Manually renaming to "BZ_FactorScore".
*Now, running for Yellow Pages:

FACTOR
  /VARIABLES ZYPTradPerf_impu ZYPSEPerf_impu ZYPUtilPerf_impu ZYPCharPerf_impu ZYPEgalPerf_impu 
    ZYPNeighPerf_impu ZYPFormPerf_impu ZYPExhiPerf_impu ZYPGlamPerf_impu ZYPTransPerf_impu 
    ZYPRatPerf_impu ZYPLocalPerf_impu ZYPStatePerf_impu ZYPCorpPerf_impu ZYPEthnPerf_impu
  /MISSING LISTWISE 
  /ANALYSIS ZYPTradPerf_impu ZYPSEPerf_impu ZYPUtilPerf_impu ZYPCharPerf_impu ZYPEgalPerf_impu 
    ZYPNeighPerf_impu ZYPFormPerf_impu ZYPExhiPerf_impu ZYPGlamPerf_impu ZYPTransPerf_impu 
    ZYPRatPerf_impu ZYPLocalPerf_impu ZYPStatePerf_impu ZYPCorpPerf_impu ZYPEthnPerf_impu
  /PRINT UNIVARIATE INITIAL EXTRACTION FSCORE
  /CRITERIA FACTORS(1) ITERATE(25)
  /EXTRACTION PC
  /ROTATION NOROTATE
  /SAVE REG(ALL)
  /METHOD=CORRELATION.

*Manually renaming the score to "YP_FactorScore".

*And then saving as a new file...

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-4if.sav'
  /COMPRESSED.

******
*Next step (entry #21 in Eric logfile #3):  merging in data that I have available already.
*From SHB syntax, first step:  merging in county density data first.

*First, sorting the merge file by countcen:

SORT CASES BY countcen(A).

*Now, opening the county density data file:

GET
  FILE='/Users/erogers/Documents/Scenes/Data/Old Merges/Merge17/Density Src '+
    'Files/county_area_pop_fixed.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

SORT CASES BY countcen(A).

*Switching back to main merge file as active file.
*Now, the merge, dropping the same vars that Sam dropped in his syntax when he did this merge:

MATCH FILES /FILE=*
  /TABLE='DataSet2'
  /RENAME (county_dens2000 fips placename state statename V12 = d0 d1 d2 d3 d4 d5)
  /BY  countcen
  /DROP= d0 d1 d2 d3 d4 d5.
EXECUTE.

*Manually renamed the land area measure to emphasize that it's county.
*Still need to do some computes, using adaptations of Sam's syntax:

COMPUTE countdens_2000=county_pop2000/county_area_sqmi.
EXECUTE.

COMPUTE countdens_1990=county_pop1990/county_area_sqmi.
EXECUTE.

COMPUTE countdens_1980=county_pop1980/county_area_sqmi.
EXECUTE.

*Descriptives look good.  Saving as a new merge iteration.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-5.sav'
  /COMPRESSED.

***Now moving on to ZIP density work.
*First, sort the merge file by zipcode.

SORT CASES BY zipcode(A).

*Then opening the zip-level file and sorting it as well:

GET
  FILE='/Users/erogers/Documents/Scenes/Data/Old Merges/Merge17/Density Src '+
    'Files/zip_area_pop(1).sav'.
DATASET NAME DataSet3 WINDOW=FRONT.

SORT CASES BY zipcode(A).

*Now doing the merge.  The main merge file is the active file.

MATCH FILES /FILE=*
  /TABLE='DataSet3'
  /RENAME (filter_$ PrimaryLast PrimaryLast1 state zip_housing zip_pop2000 = d0 d1 d2 d3 d4 d5)
  /BY  zipcode
  /DROP= d0 d1 d2 d3 d4 d5.
EXECUTE.

COMPUTE popdens_zip=TotalPop / zip_landarea_sqmi.
VARIABLE LABELS  popdens_zip 'zip population density (totalpop)[2000]/sq mi land area'.
EXECUTE.

*Descriptives look good.  Saving as a new merge iteration.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-6.sav'
  /COMPRESSED.

***Now merging in the patent data, drawing exactly from my old syntax (4/28/08):

GET
  FILE='/Users/erogers/Documents/Scenes/Data/Patents/pats9_county.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

SORT CASES BY countcen(A).

*Opening the new mergefile as active, and sorting it by countcen as well.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-6.sav'.
DATASET NAME DataSet4 WINDOW=FRONT.

SORT CASES BY countcen(A).

*Closing the patents file, and now the merge:

MATCH FILES /FILE=*
 /TABLE='/Users/erogers/Documents/Scenes/Data/Patents/pats9_county.sav'
 /BY countcen.
EXECUTE.

*Looks good, saving as a new merge iteration.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-7.sav'
  /COMPRESSED.


***Now merging in the CCDB stuff, also drawing from my syntax.
*Both files needed are already saved ascending on countcen, so just merging:

MATCH FILES /FILE=*
  /TABLE='/Users/erogers/Documents/Scenes/Data/CCDB-Tourism/countytourism4.sav'
  /RENAME (change_eatdrinksales_97_82 change_rtlemps_87_82 change_rtlemps_97_82 
    change_rtlemps_97_87 change_rtlestabs_87_82 change_rtlestabs_97_82 change_rtlestabs_97_87 
    change_rtlpayroll_87_82 change_rtlpayroll_97_82 change_rtlpayroll_97_87 change_rtlsales_87_82 
    change_rtlsales_97_82 change_rtlsales_97_87 countyfips state stfips = d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 
    d10 d11 d12 d13 d14 d15)
  /BY  countcen
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15.
EXECUTE.

*Looks right, and the Ns look good, so this should be saved as a new iteration.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-8.sav'
  /COMPRESSED.


******
*Per TNC email from 9/23, want to compute an alternate version of the factor score from bizzip.
*Want to multiply it by -1 so that the signs line up with the other two sources..****NOTE*****Superseded by work below 10/17

*Opening the most recent file.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-8.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

compute DDB_FactorScore_Flip=DDB_FactorScore * (-1).
execute.

*Manually labeled variable.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-8a.sav'
  /COMPRESSED.

********************
*9/24/08
*Working on school data.  First, need to import it into SPSS form.

GET DATA
  /TYPE=XLS
  /FILE='/Users/erogers/Documents/Scenes/Data/Schools Data/schoolsdata-cut.xls'
  /SHEET=name 'Sheet1'
  /CELLRANGE=full
  /READNAMES=on
  /ASSUMEDSTRWIDTH=400.
DATASET NAME DataSet1 WINDOW=FRONT.

*This mostly worked, but misses some of the variable names for some reason, as well as importing a bunch of blank columns/variables.
*Fixing those things by hand, with reference to the original file, and added better var names and labels.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/Schools Data/education-quotient.sav'
  /COMPRESSED.

************************
*10/13/08
*Merging in age group change variables.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-8a.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

SORT CASES BY zipcode(A).

GET
  FILE='/Users/erogers/Documents/Scenes/Data/Primary Data '+
    'Sources/TNC90_2000.2.AddsVarLabelsFromDanSyntax.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

SORT CASES BY zipcode(A).

*Making MergeB-8a active again.  And now, the merge:

MATCH FILES /FILE=*
  /TABLE='DataSet2'
  /RENAME (Age10_11 Age12_13 Age14 Age15 Age16 Age17 Age18 Age18_24_2000 Age18_24_90 Age19 Age1_2 
    Age20 Age21 Age22_24 Age25_29 Age25_34_2000 Age25_34_90 Age30_34 Age35_39 Age3_4 Age40_44 Age45_49 
    Age5 Age50_54 Age55_59 Age6 Age60_61 Age62_64 Age65_69 Age70_74 Age75_79 Age7_9 Age80_84 Age85p 
    Ageu1 AggFamIncome_200000p AggFamIncome_99 AggFamIncome_under200000 AggHHIncome_200000p 
    AggHHIncome_99 AggHHIncome_under200000 AggIncome AggTravelTime_Work AreaKey AreaName AreaName1 
    Asian BabyBoom_2000 BabyBoom_90 Black Bro_Sis checkur1 checkurb Childadopted Childnatborn Childstep 
    CMSA CNTY CNTYSC df18_24yrs df25_34yrs Df_CollegeGrads Df_GradProfDeg dfBabyBoomers dfChRur dfChUrb 
    DfFamMedianIncome DfFHHldrLA DfFHHldrNLA DfFHHldrNoHus_noChild DfFHHldrNoHus_wChild 
    DfHHMedianIncome DfLevelFHHldrLA DfLevelFHHldrNLA DfLevelFHHldrNoHus_noChild 
    DfLevelFHHldrNoHus_wChild DfLevelMHHldrLA DfLevelMHHldrNLA DfLevelMHHldrNoWife_noChild 
    DfLevelMHHldrNoWife_wChild dfLevelNonWhite dfLevelWhite DfMHHldrLA DfMHHldrNLA 
    DfMHHldrNoWife_noChild DfMHHldrNoWife_wChild dfNonWhite dfPop dfRetirees dfWhite DrvBus DrvFerry 
    DrvOther DrvRail DrvStCar DrvSubwa DrvTaxi Edu0_8 Edu9_12 EduAsoDg EduBchDg EduGrPrf EduHsGED 
    EduSmCol EXTCITIN F10Grd_25p F11Grd_25p F12Grd_25p F5_6Grd25p F65pHead F65pNRel F65pOtRe F65pSpse 
    F7_8Grd25p F9Grd_25p FamChild FamGrChi FamHead FamHH_15_64 FamHH_TotalHHldr65p FamI150p Families 
    FamIn150 FamIncome100000_124999 FamIncome10000_14999 FamIncome125000_149999 FamIncome150000_199999 
    FamIncome15000_19999 FamIncome200000p FamIncome20000_24999 FamIncome25000_29999 
    FamIncome30000_34999 FamIncome35000_39999 FamIncome40000_44999 FamIncome45000_49999 
    FamIncome50000_59999 FamIncome60000_74999 FamIncome75000_99999 FamIncome_under10000 FamNonRe 
    FamOthRe FamSpous FamStpCh Farm FAssocDeg_25p FBacDeg_25p FCollege_1pyr_25p FCollege_1yr_25p 
    FDocDeg_25p Female0_1 Female1 Female10 Female11 Female12 Female13 Female14 Female15 Female16 
    Female17 Female18 Female19 Female2 Female20 Female21 Female22_24 Female25_29 Female3 Female30_34 
    Female35_39 Female4 Female40_44 Female45_49 Female5 Female50_54 Female55_59 Female6 Female60_61 
    Female62_64 Female65_66 Female67_69 Female7 Female70_74 Female75_79 Female8 Female80_84 
    Female85plus Female9 Females FHH15_24 FHH25_34 FHH35_44 FHH45_54 FHH55_64 FHH65_74 FHH75p 
    FHHldernohus_under150 FHHldr_65p FHHldr_nohus FHHldr_nohusabove150 FHHldr_nonfam_65p 
    FHHldr_nonFamabove150 FHHldr_nonfamHH FHHldr_nonFamunder150 FHHldr_OtherFamHH_HHldr65p 
    FHHldrNoHus_otherfamHH15_64 FHighSchGrad_25p Fi12499 Fi124999 Fi14999 Fi149999 Fi150kp Fi17499 
    Fi19999 Fi22499 Fi24999 Fi27499 Fi29999 Fi32499 Fi34999 Fi37499 Fi39999 Fi42499 Fi44999 Fi47499 
    Fi4999 Fi49999 Fi54999 Fi59999 Fi74999 Fi9999 Fi99999 FMasDeg_25p FnHChu18 FnHNoChi FNoSchooling25p 
    FNursery_4thGrd25p FProfDeg_25p Ftotalpop25p GQ65pfil GQ65pIns GQ65pOth Grandchild HAsian HBLack 
    HH_1person_F HH_1person_M HH_noEarnings HH_wEarnings HHfam_above150 HHfam_under150 
    HHIncome100000_124999 HHIncome10000_14999 HHIncome125000_149999 HHIncome150000_199999 
    HHIncome15000_19999 HHIncome200000p HHIncome20000_24999 HHIncome25000_29999 HHIncome30000_34999 
    HHIncome35000_39999 HHIncome40000_44999 HHIncome45000_49999 HHIncome50000_59999 HHIncome60000_74999 
    HHIncome75000_99999 HHIncomeunder10000 HHldr HHldr15_64 HHldrF HHldrM HHMarriedFam_above150 
    HHMarriedFam_under150 HHnonFam_above150 HHnonFam_under150 HHOtherFam_above150 HHOtherFam_under150 
    HHPovStat_above150 HHPovStat_under150 Hi12499 Hi124999 Hi14999 Hi149999 HI150kp Hi150kp_A Hi17999 
    Hi19999 Hi22499 Hi24999 Hi27499 Hi29999 Hi32499 Hi34999 Hi37499 Hi39999 Hi42499 Hi44999 Hi47499 
    Hi4999 Hi49999 Hi54999 Hi59999 Hi74999 Hi9999 Hi99999 HisAsPac HisBlack HisNatAm HisOthRa Hispanic 
    HisWhite HIu150k HMixed HNativeAm HOther HousHlds HPacific HsNoEarn HsWiEarn 
    HusbandinLabor_MarridFam HWhite IncomeabovePov12_17yrs IncomeabovePov18_64yrs IncomeabovePov5yrs 
    IncomeabovePov65_74yrs IncomeabovePov6_11yrs IncomeabovePov75pyrs IncomeabovePov_under5yrs 
    IncomeabovePoverty IncomebelowPov12_17yrs IncomebelowPov18_64yrs IncomebelowPov5yrs 
    IncomebelowPov65_74yrs IncomebelowPov6_11yrs IncomebelowPov75pyrs IncomebelowPov_under5yrs 
    IncomebelowPoverty InfamHH InFamHH_65p InHH InHH_65p InNonFamHH inst_pop InstPop_65p InUrban 
    IpMcCh17 IpMcCh4 IpMcCh5 IpNhCh17 IpNhCh4 IpNhCh5 IpNwCh17 IpNwCh4 IpNwCh5 L_16pWkr L_OthTra 
    L_PubTra L_TrvTim L_WlkHom L_WrkFor LevelAge18_24_2000 LevelAge18_24_90 LevelAge25_34_2000 
    LevelAge25_34_90 LevelBabyBoom_2000 LevelBabyBoom_90 LevelNonWhite_2000 LevelNonWhite_90 
    LevelRetirees_2000 LevelRetirees_90 LevelWhite_2000 LevelWhite_90 Livingalone_F 
    Livingalone_FHHldr_65p livingalone_m Livingalone_MHHldr_65p livingalone_NonFam15_64 
    Livingalone_nonFamHH_HHldr65p Lv10_11 Lv11_12 Lv12_4p Lv12_5 Lv4_12p Lv53_6 Lv5_53 Lv63_7 Lv6_63 
    Lv73_8 Lv7_73 Lv83_9 Lv8_83 Lv9_10 LvWkHom M10Grd25p M11Grd25p M12Grd25p M5_6Grd25p M6_8Grd25p 
    M_9Grd25p M_BacDeg25p M_DocDeg25p M_MasDeg25p M_NoSchooling25p M_Nursery_4thGrd25p M_ProfDeg25p 
    M_totalpop25p Male0_1 Male1 Male10 Male11 Male12 Male13 Male14 Male15 Male16 Male17 Male18 Male19 
    Male2 Male20 Male21 Male22_24 Male25_29 Male3 Male30_34 Male35_39 Male4 Male40_44 Male45_49 Male5 
    Male50_54 Male55_59 Male6 Male60_61 Male62_64 Male65_66 Male67_69 Male7 Male70_74 Male75_79 Male8 
    Male80_84 Male85plus Male9 Males MarriedFam MarriedFamHH MArriedFamHH15_64 MarriedFamHH_HHldr65p 
    MAssocDeg_25p MCChu18 MCNoChld MCollege_1pyr25p MCollege_1yr25p MedFamI MedHsInc MedianFamIncome 
    MedianHHIncome MHHldr_65p MHHldr_nonfam_65p MHHldr_nonFamabove150 MHHldr_nonfamHH 
    MHHldr_nonFamunder150 MHHldr_nowife MHHldr_nowifeabove150 MHHldr_OtherFamHH_HHldr65p 
    MHHldrNoWife_otherfamHH15_64 MHHldrnowife_under150 MHighSchGrad_25p Mixed MnWChu18 MnWNoChl MSACMSA 
    MSACMSAS Nativeamerican NF65pFAl NF65pFNA NF65pMAl NF65pMNA NF65pNRl NF_FAlon NF_fille NF_FNAlo 
    NF_GCIns NF_GCOth NF_MAlon NF_MNAlo NF_NonRe NFH15_24 NFH25_34 NFH35_44 NFH45_54 NFH55_64 NFH65_74 
    NFH75p NHAsian NHBlack NHMixed NHNativeAm NHoAsPac NHoBlack NHoNatAm NHoOthRa NHOther NHoWhite 
    NHPacific NHWhite Nip0_4 Nip12_17 Nip18_24 Nip25_34 Nip35_44 Nip45_54 Nip5 Nip55_59 Nip60_64 
    Nip65_74 Nip6_11 Nip75p NoChild Nochild0_17_marriedfam15_64 NoChild_FHHldr_otherfam15_64 
    NoCHild_FHHldr_OtherFamHH_HHldr65p NoChild_MarriedfamHH_HHldr65p NoChild_mHHldr_otherfamHH15_64 
    NoCHild_MHHldr_OtherFamHH_HHldr65p NoChild_Other_F NoChild_Other_M Nonfam Nonfam_NonRel_65p 
    NonFamHH NonFamHH15_64 NonFamHH_HHldr65p Nonfarm NonRel NonRel_65p NonRel_nonfam NonWhite_2000 
    NonWhite_90 Nothispanic notInstPop_65p notint_pop Notlivingalone_F Notlivingalone_FHHldr_65p 
    notlivingalone_m Notlivingalone_NonFam15_64 NotLivingalone_nonFamHH_HHldr65p 
    Notlivingalong_MHHldr_65p NotWorkatHome NpMcCh17 NpMcCh4 NpMcCh5 NpNhCh17 NpNhCh4 NpNhCh5 NpNwCh17 
    NpNwCh4 NpNwCh5 Other OtherFamHH OtherFamHH15_64 OtherfamHH_HHldr65p OtherRel OtherRel_65p OutUrban 
    P001001 P002001 P003001 Pacific Parent parent_65p PctInSam Pctinsample Per100 per18_24yrs 
    per25_34yrs Per_CollegeGrads Per_GradProfDeg perBabyBoomers PerCapI PerCapitaIncome PerChRur 
    PerChUrb PerFamMedianIncome PerFHHldrLA PerFHHldrNLA PerFHHldrNoHus_noChild PerFHHldrNoHus_wChild 
    PerHHMedianIncome PerHs1 PerHs2 PerHs3 PerHs4 PerHs5 PerHs6 PerHs7p PerMHHldrLA PerMHHldrNLA 
    PerMHHldrNoWife_noChild PerMHHldrNoWife_wChild perNonWhite perRetirees perru1 perrur perur1 perurb 
    PerUSamp perWhite PMSA POP100 PopAsPac PopBlack PopNatAm PopOther PopWhite Pov0_4 Pov12_17 Pov18_24 
    Pov25_34 Pov35_44 Pov45_54 Pov5 Pov55_59 Pov60_64 Pov65_74 Pov6_11 Pov75p PovR1_24 PovR1_49 
    PovR1_74 PovR1_84 PovR1_99 PovR2p PovR_49 PovR_74 PovR_99 PovStat125_149 PovStat150_174 
    PovStat175_184 PovStat185_199 PovStat1_124 PovStat2p PovStat50_74 PovStat75_99 PovStat_under50 
    Retirees_2000 Retirees_90 Rural RurFarm RurNoFrm S_RurPop S_TotPop S_UrbPop Spouse spouse_65p 
    STUSAB Tim0_4 Tim10_14 Tim15_19 Tim20_24 Tim25_29 Tim30_24 Tim35_39 Tim40_44 Tim45_59 Tim5_9 
    Tim60_89 Tim90p TimTot TimWkHom Total_HH Totalchild TotalFam TotalFam_I TotalFemale TotalGrpQtrs 
    TotalHH1 TotalHH_1person TotalHH_2ormore TotalHH_E TotalHH_Fam TotalHH_I TotalHH_Povstat 
    TotalHHldr65p TotalHHldr_65p TotalHHldrF_nonfam TotalHHldrM_nonfam TotalInGrpQtrs_65p 
    TotalInNonFamHH_65p TotalMale TotalPop Totalpop1 Totalpop2 TotalPop3 TotalPop4 TotalPop_25p 
    TotalPop_65plus TotalPop_Povstat TotalPop_PovStat1 TotalWorker_16p TotalWorker_16p1 
    TotalWorkers16p_NotWorkatHome TotPop90 TRACT UASC Urban URBANRUR URBAREA Urbclusters V10 V100 V101 
    V102 V103 V104 V105 V106 V107 V108 V109 V11 V110 V111 V112 V113 V114 V115 V116 V117 V118 V119 V12 
    V120 V121 V122 V123 V124 V13 V132 V14 V15 V16 V167 V19 V20 V21 V22 V23 V24 V25 V26 V27 V28 V29 V30 
    V32 V33 V34 V35 V36 V37 V38 V39 V4 V40 V41 V42 V43 V45 V46 V47 V48 V49 V5 V50 V51 V52 V53 V54 V55 
    V56 V57 V58 V59 V6 V60 V7 V8 V9 V99 wChild0_17 wChild0_17_marriedfam15_64 wChild0_17_Other_F 
    wChild0_17_Other_M wChild_FHHldr_otherfam15_64 wCHild_FHHldr_OtherFamHH_HHldr65p 
    wChild_MariedfamHH_HHldr65p wChild_mHHldr_otherfamHH15_64 wCHild_MHHldr_OtherFamHH_HHldr65p White 
    White_2000 White_90 WkInFm0 WkInFm1 WkInFm2 WkInFm3p Workedathome ZIP = d0 d1 d2 d3 d4 d5 d6 d7 d8 
    d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31 d32 d33 
    d34 d35 d36 d37 d38 d39 d40 d41 d42 d43 d44 d45 d46 d47 d48 d49 d50 d51 d52 d53 d54 d55 d56 d57 d58 
    d59 d60 d61 d62 d63 d64 d65 d66 d67 d68 d69 d70 d71 d72 d73 d74 d75 d76 d77 d78 d79 d80 d81 d82 d83 
    d84 d85 d86 d87 d88 d89 d90 d91 d92 d93 d94 d95 d96 d97 d98 d99 d100 d101 d102 d103 d104 d105 d106 
    d107 d108 d109 d110 d111 d112 d113 d114 d115 d116 d117 d118 d119 d120 d121 d122 d123 d124 d125 d126 
    d127 d128 d129 d130 d131 d132 d133 d134 d135 d136 d137 d138 d139 d140 d141 d142 d143 d144 d145 d146 
    d147 d148 d149 d150 d151 d152 d153 d154 d155 d156 d157 d158 d159 d160 d161 d162 d163 d164 d165 d166 
    d167 d168 d169 d170 d171 d172 d173 d174 d175 d176 d177 d178 d179 d180 d181 d182 d183 d184 d185 d186 
    d187 d188 d189 d190 d191 d192 d193 d194 d195 d196 d197 d198 d199 d200 d201 d202 d203 d204 d205 d206 
    d207 d208 d209 d210 d211 d212 d213 d214 d215 d216 d217 d218 d219 d220 d221 d222 d223 d224 d225 d226 
    d227 d228 d229 d230 d231 d232 d233 d234 d235 d236 d237 d238 d239 d240 d241 d242 d243 d244 d245 d246 
    d247 d248 d249 d250 d251 d252 d253 d254 d255 d256 d257 d258 d259 d260 d261 d262 d263 d264 d265 d266 
    d267 d268 d269 d270 d271 d272 d273 d274 d275 d276 d277 d278 d279 d280 d281 d282 d283 d284 d285 d286 
    d287 d288 d289 d290 d291 d292 d293 d294 d295 d296 d297 d298 d299 d300 d301 d302 d303 d304 d305 d306 
    d307 d308 d309 d310 d311 d312 d313 d314 d315 d316 d317 d318 d319 d320 d321 d322 d323 d324 d325 d326 
    d327 d328 d329 d330 d331 d332 d333 d334 d335 d336 d337 d338 d339 d340 d341 d342 d343 d344 d345 d346 
    d347 d348 d349 d350 d351 d352 d353 d354 d355 d356 d357 d358 d359 d360 d361 d362 d363 d364 d365 d366 
    d367 d368 d369 d370 d371 d372 d373 d374 d375 d376 d377 d378 d379 d380 d381 d382 d383 d384 d385 d386 
    d387 d388 d389 d390 d391 d392 d393 d394 d395 d396 d397 d398 d399 d400 d401 d402 d403 d404 d405 d406 
    d407 d408 d409 d410 d411 d412 d413 d414 d415 d416 d417 d418 d419 d420 d421 d422 d423 d424 d425 d426 
    d427 d428 d429 d430 d431 d432 d433 d434 d435 d436 d437 d438 d439 d440 d441 d442 d443 d444 d445 d446 
    d447 d448 d449 d450 d451 d452 d453 d454 d455 d456 d457 d458 d459 d460 d461 d462 d463 d464 d465 d466 
    d467 d468 d469 d470 d471 d472 d473 d474 d475 d476 d477 d478 d479 d480 d481 d482 d483 d484 d485 d486 
    d487 d488 d489 d490 d491 d492 d493 d494 d495 d496 d497 d498 d499 d500 d501 d502 d503 d504 d505 d506 
    d507 d508 d509 d510 d511 d512 d513 d514 d515 d516 d517 d518 d519 d520 d521 d522 d523 d524 d525 d526 
    d527 d528 d529 d530 d531 d532 d533 d534 d535 d536 d537 d538 d539 d540 d541 d542 d543 d544 d545 d546 
    d547 d548 d549 d550 d551 d552 d553 d554 d555 d556 d557 d558 d559 d560 d561 d562 d563 d564 d565 d566 
    d567 d568 d569 d570 d571 d572 d573 d574 d575 d576 d577 d578 d579 d580 d581 d582 d583 d584 d585 d586 
    d587 d588 d589 d590 d591 d592 d593 d594 d595 d596 d597 d598 d599 d600 d601 d602 d603 d604 d605 d606 
    d607 d608 d609 d610 d611 d612 d613 d614 d615 d616 d617 d618 d619 d620 d621 d622 d623 d624 d625 d626 
    d627 d628 d629 d630 d631 d632 d633 d634 d635 d636 d637 d638 d639 d640 d641 d642 d643 d644 d645 d646 
    d647 d648 d649 d650 d651 d652 d653 d654 d655 d656 d657 d658 d659 d660 d661 d662 d663 d664 d665 d666 
    d667 d668 d669 d670 d671 d672 d673 d674 d675 d676 d677 d678 d679 d680 d681 d682 d683 d684 d685 d686 
    d687 d688 d689 d690 d691 d692 d693 d694 d695 d696 d697 d698 d699 d700 d701 d702 d703 d704 d705 d706 
    d707 d708 d709 d710 d711 d712 d713 d714 d715 d716 d717 d718 d719 d720 d721 d722 d723 d724 d725 d726 
    d727 d728 d729 d730 d731 d732 d733 d734 d735 d736 d737 d738 d739 d740 d741 d742 d743 d744 d745 d746 
    d747 d748 d749 d750 d751 d752 d753 d754 d755 d756 d757 d758 d759 d760 d761 d762 d763 d764 d765 d766 
    d767 d768 d769 d770 d771 d772 d773 d774 d775 d776 d777 d778 d779 d780 d781 d782 d783 d784 d785 d786 
    d787 d788 d789 d790 d791 d792 d793 d794 d795 d796 d797 d798 d799 d800 d801 d802 d803 d804 d805 d806)    
  /BY  zipcode
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 
    d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36 d37 d38 d39 d40 d41 d42 d43 d44 d45 d46 d47 d48 d49 
    d50 d51 d52 d53 d54 d55 d56 d57 d58 d59 d60 d61 d62 d63 d64 d65 d66 d67 d68 d69 d70 d71 d72 d73 d74 
    d75 d76 d77 d78 d79 d80 d81 d82 d83 d84 d85 d86 d87 d88 d89 d90 d91 d92 d93 d94 d95 d96 d97 d98 d99 
    d100 d101 d102 d103 d104 d105 d106 d107 d108 d109 d110 d111 d112 d113 d114 d115 d116 d117 d118 d119 
    d120 d121 d122 d123 d124 d125 d126 d127 d128 d129 d130 d131 d132 d133 d134 d135 d136 d137 d138 d139 
    d140 d141 d142 d143 d144 d145 d146 d147 d148 d149 d150 d151 d152 d153 d154 d155 d156 d157 d158 d159 
    d160 d161 d162 d163 d164 d165 d166 d167 d168 d169 d170 d171 d172 d173 d174 d175 d176 d177 d178 d179 
    d180 d181 d182 d183 d184 d185 d186 d187 d188 d189 d190 d191 d192 d193 d194 d195 d196 d197 d198 d199 
    d200 d201 d202 d203 d204 d205 d206 d207 d208 d209 d210 d211 d212 d213 d214 d215 d216 d217 d218 d219 
    d220 d221 d222 d223 d224 d225 d226 d227 d228 d229 d230 d231 d232 d233 d234 d235 d236 d237 d238 d239 
    d240 d241 d242 d243 d244 d245 d246 d247 d248 d249 d250 d251 d252 d253 d254 d255 d256 d257 d258 d259 
    d260 d261 d262 d263 d264 d265 d266 d267 d268 d269 d270 d271 d272 d273 d274 d275 d276 d277 d278 d279 
    d280 d281 d282 d283 d284 d285 d286 d287 d288 d289 d290 d291 d292 d293 d294 d295 d296 d297 d298 d299 
    d300 d301 d302 d303 d304 d305 d306 d307 d308 d309 d310 d311 d312 d313 d314 d315 d316 d317 d318 d319 
    d320 d321 d322 d323 d324 d325 d326 d327 d328 d329 d330 d331 d332 d333 d334 d335 d336 d337 d338 d339 
    d340 d341 d342 d343 d344 d345 d346 d347 d348 d349 d350 d351 d352 d353 d354 d355 d356 d357 d358 d359 
    d360 d361 d362 d363 d364 d365 d366 d367 d368 d369 d370 d371 d372 d373 d374 d375 d376 d377 d378 d379 
    d380 d381 d382 d383 d384 d385 d386 d387 d388 d389 d390 d391 d392 d393 d394 d395 d396 d397 d398 d399 
    d400 d401 d402 d403 d404 d405 d406 d407 d408 d409 d410 d411 d412 d413 d414 d415 d416 d417 d418 d419 
    d420 d421 d422 d423 d424 d425 d426 d427 d428 d429 d430 d431 d432 d433 d434 d435 d436 d437 d438 d439 
    d440 d441 d442 d443 d444 d445 d446 d447 d448 d449 d450 d451 d452 d453 d454 d455 d456 d457 d458 d459 
    d460 d461 d462 d463 d464 d465 d466 d467 d468 d469 d470 d471 d472 d473 d474 d475 d476 d477 d478 d479 
    d480 d481 d482 d483 d484 d485 d486 d487 d488 d489 d490 d491 d492 d493 d494 d495 d496 d497 d498 d499 
    d500 d501 d502 d503 d504 d505 d506 d507 d508 d509 d510 d511 d512 d513 d514 d515 d516 d517 d518 d519 
    d520 d521 d522 d523 d524 d525 d526 d527 d528 d529 d530 d531 d532 d533 d534 d535 d536 d537 d538 d539 
    d540 d541 d542 d543 d544 d545 d546 d547 d548 d549 d550 d551 d552 d553 d554 d555 d556 d557 d558 d559 
    d560 d561 d562 d563 d564 d565 d566 d567 d568 d569 d570 d571 d572 d573 d574 d575 d576 d577 d578 d579 
    d580 d581 d582 d583 d584 d585 d586 d587 d588 d589 d590 d591 d592 d593 d594 d595 d596 d597 d598 d599 
    d600 d601 d602 d603 d604 d605 d606 d607 d608 d609 d610 d611 d612 d613 d614 d615 d616 d617 d618 d619 
    d620 d621 d622 d623 d624 d625 d626 d627 d628 d629 d630 d631 d632 d633 d634 d635 d636 d637 d638 d639 
    d640 d641 d642 d643 d644 d645 d646 d647 d648 d649 d650 d651 d652 d653 d654 d655 d656 d657 d658 d659 
    d660 d661 d662 d663 d664 d665 d666 d667 d668 d669 d670 d671 d672 d673 d674 d675 d676 d677 d678 d679 
    d680 d681 d682 d683 d684 d685 d686 d687 d688 d689 d690 d691 d692 d693 d694 d695 d696 d697 d698 d699 
    d700 d701 d702 d703 d704 d705 d706 d707 d708 d709 d710 d711 d712 d713 d714 d715 d716 d717 d718 d719 
    d720 d721 d722 d723 d724 d725 d726 d727 d728 d729 d730 d731 d732 d733 d734 d735 d736 d737 d738 d739 
    d740 d741 d742 d743 d744 d745 d746 d747 d748 d749 d750 d751 d752 d753 d754 d755 d756 d757 d758 d759 
    d760 d761 d762 d763 d764 d765 d766 d767 d768 d769 d770 d771 d772 d773 d774 d775 d776 d777 d778 d779 
    d780 d781 d782 d783 d784 d785 d786 d787 d788 d789 d790 d791 d792 d793 d794 d795 d796 d797 d798 d799 
    d800 d801 d802 d803 d804 d805 d806.
EXECUTE.

*Checking descriptives of the new vars and overall file.

DESCRIPTIVES VARIABLES=zipcode chPop dfLevel18_24yrs dfLevel25_34yrs dfLevelBabyBoomers 
    dfLevelRetirees DfLevel_CollegeGrads DfLevel_GradProfDeg
  /STATISTICS=MEAN STDDEV MIN MAX.

*Total case count for file is still 42192, and Ns for the added variables are exactly as in the source files.  It worked.
*Saving as new file, augmenting merge counter.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-9.sav'
  /COMPRESSED.

*Now, need to use chPop to compute the variable we need for the core.  (See TNC syntax 3, line 7493.)

compute chpop1 = chpop +.001.
compute LnChPop290 = Ln(chpop1). 
execute.

*Checking N...

DESCRIPTIVES VARIABLES=zipcode chPop chpop1 LnChPop290
  /STATISTICS=MEAN STDDEV MIN MAX.

*Great, N still 28223 for new vars, as it should be.  Saving, adding a letter to indicate a compute was done.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-9a.sav'
  /COMPRESSED.

******************************
*10/13/08
*Merging in income-related vars for a compute of core variable.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-9a.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

SORT CASES BY zipcode(A).

GET
  FILE='/Users/erogers/Documents/Scenes/Data/Primary Data '+
    'Sources/TNC90_2000.2.AddsVarLabelsFromDanSyntax.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

SORT CASES BY zipcode(A).

*Switching back main data file to active, and now the merge:

MATCH FILES /FILE=*
  /TABLE='DataSet2'
  /RENAME (Age10_11 Age12_13 Age14 Age15 Age16 Age17 Age18 Age18_24_2000 Age18_24_90 Age19 Age1_2 
    Age20 Age21 Age22_24 Age25_29 Age25_34_2000 Age25_34_90 Age30_34 Age35_39 Age3_4 Age40_44 Age45_49 
    Age5 Age50_54 Age55_59 Age6 Age60_61 Age62_64 Age65_69 Age70_74 Age75_79 Age7_9 Age80_84 Age85p 
    Ageu1 AggFamIncome_200000p AggFamIncome_99 AggFamIncome_under200000 AggHHIncome_200000p 
    AggHHIncome_99 AggHHIncome_under200000 AggIncome AggTravelTime_Work AreaKey AreaName AreaName1 
    Asian BabyBoom_2000 BabyBoom_90 Black Bro_Sis checkur1 checkurb Childadopted Childnatborn Childstep 
    chPop CMSA CNTY CNTYSC df18_24yrs df25_34yrs Df_CollegeGrads Df_GradProfDeg dfBabyBoomers dfChRur 
    dfChUrb DfFamMedianIncome DfFHHldrLA DfFHHldrNLA DfFHHldrNoHus_noChild DfFHHldrNoHus_wChild 
    DfHHMedianIncome dfLevel18_24yrs dfLevel25_34yrs DfLevel_CollegeGrads DfLevel_GradProfDeg 
    dfLevelBabyBoomers DfLevelFHHldrLA DfLevelFHHldrNLA DfLevelFHHldrNoHus_noChild 
    DfLevelFHHldrNoHus_wChild DfLevelMHHldrLA DfLevelMHHldrNLA DfLevelMHHldrNoWife_noChild 
    DfLevelMHHldrNoWife_wChild dfLevelNonWhite dfLevelRetirees dfLevelWhite DfMHHldrLA DfMHHldrNLA 
    DfMHHldrNoWife_noChild DfMHHldrNoWife_wChild dfNonWhite dfPop dfRetirees dfWhite DrvBus DrvFerry 
    DrvOther DrvRail DrvStCar DrvSubwa DrvTaxi Edu0_8 Edu9_12 EduAsoDg EduBchDg EduGrPrf EduHsGED 
    EduSmCol EXTCITIN F10Grd_25p F11Grd_25p F12Grd_25p F5_6Grd25p F65pHead F65pNRel F65pOtRe F65pSpse 
    F7_8Grd25p F9Grd_25p FamChild FamGrChi FamHead FamHH_15_64 FamHH_TotalHHldr65p FamI150p Families 
    FamIn150 FamIncome100000_124999 FamIncome10000_14999 FamIncome125000_149999 FamIncome150000_199999 
    FamIncome15000_19999 FamIncome200000p FamIncome20000_24999 FamIncome25000_29999 
    FamIncome30000_34999 FamIncome35000_39999 FamIncome40000_44999 FamIncome45000_49999 
    FamIncome50000_59999 FamIncome60000_74999 FamIncome75000_99999 FamIncome_under10000 FamNonRe 
    FamOthRe FamSpous FamStpCh Farm FAssocDeg_25p FBacDeg_25p FCollege_1pyr_25p FCollege_1yr_25p 
    FDocDeg_25p Female0_1 Female1 Female10 Female11 Female12 Female13 Female14 Female15 Female16 
    Female17 Female18 Female19 Female2 Female20 Female21 Female22_24 Female25_29 Female3 Female30_34 
    Female35_39 Female4 Female40_44 Female45_49 Female5 Female50_54 Female55_59 Female6 Female60_61 
    Female62_64 Female65_66 Female67_69 Female7 Female70_74 Female75_79 Female8 Female80_84 
    Female85plus Female9 Females FHH15_24 FHH25_34 FHH35_44 FHH45_54 FHH55_64 FHH65_74 FHH75p 
    FHHldernohus_under150 FHHldr_65p FHHldr_nohus FHHldr_nohusabove150 FHHldr_nonfam_65p 
    FHHldr_nonFamabove150 FHHldr_nonfamHH FHHldr_nonFamunder150 FHHldr_OtherFamHH_HHldr65p 
    FHHldrNoHus_otherfamHH15_64 FHighSchGrad_25p Fi12499 Fi124999 Fi14999 Fi149999 Fi150kp Fi17499 
    Fi19999 Fi22499 Fi24999 Fi27499 Fi29999 Fi32499 Fi34999 Fi37499 Fi39999 Fi42499 Fi44999 Fi47499 
    Fi4999 Fi49999 Fi54999 Fi59999 Fi74999 Fi9999 Fi99999 FMasDeg_25p FnHChu18 FnHNoChi FNoSchooling25p 
    FNursery_4thGrd25p FProfDeg_25p Ftotalpop25p GQ65pfil GQ65pIns GQ65pOth Grandchild HAsian HBLack 
    HH_1person_F HH_1person_M HH_noEarnings HH_wEarnings HHfam_above150 HHfam_under150 
    HHIncome100000_124999 HHIncome10000_14999 HHIncome125000_149999 HHIncome150000_199999 
    HHIncome15000_19999 HHIncome200000p HHIncome20000_24999 HHIncome25000_29999 HHIncome30000_34999 
    HHIncome35000_39999 HHIncome40000_44999 HHIncome45000_49999 HHIncome50000_59999 HHIncome60000_74999 
    HHIncome75000_99999 HHIncomeunder10000 HHldr HHldr15_64 HHldrF HHldrM HHMarriedFam_above150 
    HHMarriedFam_under150 HHnonFam_above150 HHnonFam_under150 HHOtherFam_above150 HHOtherFam_under150 
    HHPovStat_above150 HHPovStat_under150 Hi12499 Hi124999 Hi14999 Hi149999 HI150kp Hi150kp_A Hi17999 
    Hi19999 Hi22499 Hi24999 Hi27499 Hi29999 Hi32499 Hi34999 Hi37499 Hi39999 Hi42499 Hi44999 Hi47499 
    Hi4999 Hi49999 Hi54999 Hi59999 Hi74999 Hi9999 Hi99999 HisAsPac HisBlack HisNatAm HisOthRa Hispanic 
    HisWhite HIu150k HMixed HNativeAm HOther HousHlds HPacific HsNoEarn HsWiEarn 
    HusbandinLabor_MarridFam HWhite IncomeabovePov12_17yrs IncomeabovePov18_64yrs IncomeabovePov5yrs 
    IncomeabovePov65_74yrs IncomeabovePov6_11yrs IncomeabovePov75pyrs IncomeabovePov_under5yrs 
    IncomeabovePoverty IncomebelowPov12_17yrs IncomebelowPov18_64yrs IncomebelowPov5yrs 
    IncomebelowPov65_74yrs IncomebelowPov6_11yrs IncomebelowPov75pyrs IncomebelowPov_under5yrs 
    IncomebelowPoverty InfamHH InFamHH_65p InHH InHH_65p InNonFamHH inst_pop InstPop_65p InUrban 
    IpMcCh17 IpMcCh4 IpMcCh5 IpNhCh17 IpNhCh4 IpNhCh5 IpNwCh17 IpNwCh4 IpNwCh5 L_16pWkr L_OthTra 
    L_PubTra L_TrvTim L_WlkHom L_WrkFor LevelAge18_24_2000 LevelAge18_24_90 LevelAge25_34_2000 
    LevelAge25_34_90 LevelBabyBoom_2000 LevelBabyBoom_90 LevelNonWhite_2000 LevelNonWhite_90 
    LevelRetirees_2000 LevelRetirees_90 LevelWhite_2000 LevelWhite_90 Livingalone_F 
    Livingalone_FHHldr_65p livingalone_m Livingalone_MHHldr_65p livingalone_NonFam15_64 
    Livingalone_nonFamHH_HHldr65p Lv10_11 Lv11_12 Lv12_4p Lv12_5 Lv4_12p Lv53_6 Lv5_53 Lv63_7 Lv6_63 
    Lv73_8 Lv7_73 Lv83_9 Lv8_83 Lv9_10 LvWkHom M10Grd25p M11Grd25p M12Grd25p M5_6Grd25p M6_8Grd25p 
    M_9Grd25p M_BacDeg25p M_DocDeg25p M_MasDeg25p M_NoSchooling25p M_Nursery_4thGrd25p M_ProfDeg25p 
    M_totalpop25p Male0_1 Male1 Male10 Male11 Male12 Male13 Male14 Male15 Male16 Male17 Male18 Male19 
    Male2 Male20 Male21 Male22_24 Male25_29 Male3 Male30_34 Male35_39 Male4 Male40_44 Male45_49 Male5 
    Male50_54 Male55_59 Male6 Male60_61 Male62_64 Male65_66 Male67_69 Male7 Male70_74 Male75_79 Male8 
    Male80_84 Male85plus Male9 Males MarriedFam MarriedFamHH MArriedFamHH15_64 MarriedFamHH_HHldr65p 
    MAssocDeg_25p MCChu18 MCNoChld MCollege_1pyr25p MCollege_1yr25p MedFamI MedHsInc MedianFamIncome 
    MedianHHIncome MHHldr_65p MHHldr_nonfam_65p MHHldr_nonFamabove150 MHHldr_nonfamHH 
    MHHldr_nonFamunder150 MHHldr_nowife MHHldr_nowifeabove150 MHHldr_OtherFamHH_HHldr65p 
    MHHldrNoWife_otherfamHH15_64 MHHldrnowife_under150 MHighSchGrad_25p Mixed MnWChu18 MnWNoChl MSACMSA 
    MSACMSAS Nativeamerican NF65pFAl NF65pFNA NF65pMAl NF65pMNA NF65pNRl NF_FAlon NF_fille NF_FNAlo 
    NF_GCIns NF_GCOth NF_MAlon NF_MNAlo NF_NonRe NFH15_24 NFH25_34 NFH35_44 NFH45_54 NFH55_64 NFH65_74 
    NFH75p NHAsian NHBlack NHMixed NHNativeAm NHoAsPac NHoBlack NHoNatAm NHoOthRa NHOther NHoWhite 
    NHPacific NHWhite Nip0_4 Nip12_17 Nip18_24 Nip25_34 Nip35_44 Nip45_54 Nip5 Nip55_59 Nip60_64 
    Nip65_74 Nip6_11 Nip75p NoChild Nochild0_17_marriedfam15_64 NoChild_FHHldr_otherfam15_64 
    NoCHild_FHHldr_OtherFamHH_HHldr65p NoChild_MarriedfamHH_HHldr65p NoChild_mHHldr_otherfamHH15_64 
    NoCHild_MHHldr_OtherFamHH_HHldr65p NoChild_Other_F NoChild_Other_M Nonfam Nonfam_NonRel_65p 
    NonFamHH NonFamHH15_64 NonFamHH_HHldr65p Nonfarm NonRel NonRel_65p NonRel_nonfam NonWhite_2000 
    NonWhite_90 Nothispanic notInstPop_65p notint_pop Notlivingalone_F Notlivingalone_FHHldr_65p 
    notlivingalone_m Notlivingalone_NonFam15_64 NotLivingalone_nonFamHH_HHldr65p 
    Notlivingalong_MHHldr_65p NotWorkatHome NpMcCh17 NpMcCh4 NpMcCh5 NpNhCh17 NpNhCh4 NpNhCh5 NpNwCh17 
    NpNwCh4 NpNwCh5 Other OtherFamHH OtherFamHH15_64 OtherfamHH_HHldr65p OtherRel OtherRel_65p OutUrban 
    P001001 P002001 P003001 Pacific Parent parent_65p PctInSam Pctinsample Per100 per18_24yrs 
    per25_34yrs Per_CollegeGrads Per_GradProfDeg perBabyBoomers PerChRur PerChUrb PerFamMedianIncome 
    PerFHHldrLA PerFHHldrNLA PerFHHldrNoHus_noChild PerFHHldrNoHus_wChild PerHHMedianIncome PerHs1 
    PerHs2 PerHs3 PerHs4 PerHs5 PerHs6 PerHs7p PerMHHldrLA PerMHHldrNLA PerMHHldrNoWife_noChild 
    PerMHHldrNoWife_wChild perNonWhite perRetirees perru1 perrur perur1 perurb PerUSamp perWhite PMSA 
    POP100 PopAsPac PopBlack PopNatAm PopOther PopWhite Pov0_4 Pov12_17 Pov18_24 Pov25_34 Pov35_44 
    Pov45_54 Pov5 Pov55_59 Pov60_64 Pov65_74 Pov6_11 Pov75p PovR1_24 PovR1_49 PovR1_74 PovR1_84 
    PovR1_99 PovR2p PovR_49 PovR_74 PovR_99 PovStat125_149 PovStat150_174 PovStat175_184 PovStat185_199 
    PovStat1_124 PovStat2p PovStat50_74 PovStat75_99 PovStat_under50 Retirees_2000 Retirees_90 Rural 
    RurFarm RurNoFrm S_RurPop S_TotPop S_UrbPop Spouse spouse_65p STUSAB Tim0_4 Tim10_14 Tim15_19 
    Tim20_24 Tim25_29 Tim30_24 Tim35_39 Tim40_44 Tim45_59 Tim5_9 Tim60_89 Tim90p TimTot TimWkHom 
    Total_HH Totalchild TotalFam TotalFam_I TotalFemale TotalGrpQtrs TotalHH1 TotalHH_1person 
    TotalHH_2ormore TotalHH_E TotalHH_Fam TotalHH_I TotalHH_Povstat TotalHHldr65p TotalHHldr_65p 
    TotalHHldrF_nonfam TotalHHldrM_nonfam TotalInGrpQtrs_65p TotalInNonFamHH_65p TotalMale TotalPop 
    Totalpop1 Totalpop2 TotalPop3 TotalPop4 TotalPop_25p TotalPop_65plus TotalPop_Povstat 
    TotalPop_PovStat1 TotalWorker_16p TotalWorker_16p1 TotalWorkers16p_NotWorkatHome TotPop90 TRACT 
    UASC Urban URBANRUR URBAREA Urbclusters V10 V100 V101 V102 V103 V104 V105 V106 V107 V108 V109 V11 
    V110 V111 V112 V113 V114 V115 V116 V117 V118 V119 V12 V120 V121 V122 V123 V124 V13 V132 V14 V15 V16 
    V167 V19 V20 V21 V22 V23 V24 V25 V26 V27 V28 V29 V30 V32 V33 V34 V35 V36 V37 V38 V39 V4 V40 V41 V42 
    V43 V45 V46 V47 V48 V49 V5 V50 V51 V52 V53 V54 V55 V56 V57 V58 V59 V6 V60 V7 V8 V9 V99 wChild0_17 
    wChild0_17_marriedfam15_64 wChild0_17_Other_F wChild0_17_Other_M wChild_FHHldr_otherfam15_64 
    wCHild_FHHldr_OtherFamHH_HHldr65p wChild_MariedfamHH_HHldr65p wChild_mHHldr_otherfamHH15_64 
    wCHild_MHHldr_OtherFamHH_HHldr65p White White_2000 White_90 WkInFm0 WkInFm1 WkInFm2 WkInFm3p 
    Workedathome ZIP = d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 
    d22 d23 d24 d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36 d37 d38 d39 d40 d41 d42 d43 d44 d45 d46 
    d47 d48 d49 d50 d51 d52 d53 d54 d55 d56 d57 d58 d59 d60 d61 d62 d63 d64 d65 d66 d67 d68 d69 d70 d71 
    d72 d73 d74 d75 d76 d77 d78 d79 d80 d81 d82 d83 d84 d85 d86 d87 d88 d89 d90 d91 d92 d93 d94 d95 d96 
    d97 d98 d99 d100 d101 d102 d103 d104 d105 d106 d107 d108 d109 d110 d111 d112 d113 d114 d115 d116 
    d117 d118 d119 d120 d121 d122 d123 d124 d125 d126 d127 d128 d129 d130 d131 d132 d133 d134 d135 d136 
    d137 d138 d139 d140 d141 d142 d143 d144 d145 d146 d147 d148 d149 d150 d151 d152 d153 d154 d155 d156 
    d157 d158 d159 d160 d161 d162 d163 d164 d165 d166 d167 d168 d169 d170 d171 d172 d173 d174 d175 d176 
    d177 d178 d179 d180 d181 d182 d183 d184 d185 d186 d187 d188 d189 d190 d191 d192 d193 d194 d195 d196 
    d197 d198 d199 d200 d201 d202 d203 d204 d205 d206 d207 d208 d209 d210 d211 d212 d213 d214 d215 d216 
    d217 d218 d219 d220 d221 d222 d223 d224 d225 d226 d227 d228 d229 d230 d231 d232 d233 d234 d235 d236 
    d237 d238 d239 d240 d241 d242 d243 d244 d245 d246 d247 d248 d249 d250 d251 d252 d253 d254 d255 d256 
    d257 d258 d259 d260 d261 d262 d263 d264 d265 d266 d267 d268 d269 d270 d271 d272 d273 d274 d275 d276 
    d277 d278 d279 d280 d281 d282 d283 d284 d285 d286 d287 d288 d289 d290 d291 d292 d293 d294 d295 d296 
    d297 d298 d299 d300 d301 d302 d303 d304 d305 d306 d307 d308 d309 d310 d311 d312 d313 d314 d315 d316 
    d317 d318 d319 d320 d321 d322 d323 d324 d325 d326 d327 d328 d329 d330 d331 d332 d333 d334 d335 d336 
    d337 d338 d339 d340 d341 d342 d343 d344 d345 d346 d347 d348 d349 d350 d351 d352 d353 d354 d355 d356 
    d357 d358 d359 d360 d361 d362 d363 d364 d365 d366 d367 d368 d369 d370 d371 d372 d373 d374 d375 d376 
    d377 d378 d379 d380 d381 d382 d383 d384 d385 d386 d387 d388 d389 d390 d391 d392 d393 d394 d395 d396 
    d397 d398 d399 d400 d401 d402 d403 d404 d405 d406 d407 d408 d409 d410 d411 d412 d413 d414 d415 d416 
    d417 d418 d419 d420 d421 d422 d423 d424 d425 d426 d427 d428 d429 d430 d431 d432 d433 d434 d435 d436 
    d437 d438 d439 d440 d441 d442 d443 d444 d445 d446 d447 d448 d449 d450 d451 d452 d453 d454 d455 d456 
    d457 d458 d459 d460 d461 d462 d463 d464 d465 d466 d467 d468 d469 d470 d471 d472 d473 d474 d475 d476 
    d477 d478 d479 d480 d481 d482 d483 d484 d485 d486 d487 d488 d489 d490 d491 d492 d493 d494 d495 d496 
    d497 d498 d499 d500 d501 d502 d503 d504 d505 d506 d507 d508 d509 d510 d511 d512 d513 d514 d515 d516 
    d517 d518 d519 d520 d521 d522 d523 d524 d525 d526 d527 d528 d529 d530 d531 d532 d533 d534 d535 d536 
    d537 d538 d539 d540 d541 d542 d543 d544 d545 d546 d547 d548 d549 d550 d551 d552 d553 d554 d555 d556 
    d557 d558 d559 d560 d561 d562 d563 d564 d565 d566 d567 d568 d569 d570 d571 d572 d573 d574 d575 d576 
    d577 d578 d579 d580 d581 d582 d583 d584 d585 d586 d587 d588 d589 d590 d591 d592 d593 d594 d595 d596 
    d597 d598 d599 d600 d601 d602 d603 d604 d605 d606 d607 d608 d609 d610 d611 d612 d613 d614 d615 d616 
    d617 d618 d619 d620 d621 d622 d623 d624 d625 d626 d627 d628 d629 d630 d631 d632 d633 d634 d635 d636 
    d637 d638 d639 d640 d641 d642 d643 d644 d645 d646 d647 d648 d649 d650 d651 d652 d653 d654 d655 d656 
    d657 d658 d659 d660 d661 d662 d663 d664 d665 d666 d667 d668 d669 d670 d671 d672 d673 d674 d675 d676 
    d677 d678 d679 d680 d681 d682 d683 d684 d685 d686 d687 d688 d689 d690 d691 d692 d693 d694 d695 d696 
    d697 d698 d699 d700 d701 d702 d703 d704 d705 d706 d707 d708 d709 d710 d711 d712 d713 d714 d715 d716 
    d717 d718 d719 d720 d721 d722 d723 d724 d725 d726 d727 d728 d729 d730 d731 d732 d733 d734 d735 d736 
    d737 d738 d739 d740 d741 d742 d743 d744 d745 d746 d747 d748 d749 d750 d751 d752 d753 d754 d755 d756 
    d757 d758 d759 d760 d761 d762 d763 d764 d765 d766 d767 d768 d769 d770 d771 d772 d773 d774 d775 d776 
    d777 d778 d779 d780 d781 d782 d783 d784 d785 d786 d787 d788 d789 d790 d791 d792 d793 d794 d795 d796 
    d797 d798 d799 d800 d801 d802 d803 d804 d805 d806 d807 d808 d809 d810 d811)
  /BY  zipcode
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 
    d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36 d37 d38 d39 d40 d41 d42 d43 d44 d45 d46 d47 d48 d49 
    d50 d51 d52 d53 d54 d55 d56 d57 d58 d59 d60 d61 d62 d63 d64 d65 d66 d67 d68 d69 d70 d71 d72 d73 d74 
    d75 d76 d77 d78 d79 d80 d81 d82 d83 d84 d85 d86 d87 d88 d89 d90 d91 d92 d93 d94 d95 d96 d97 d98 d99 
    d100 d101 d102 d103 d104 d105 d106 d107 d108 d109 d110 d111 d112 d113 d114 d115 d116 d117 d118 d119 
    d120 d121 d122 d123 d124 d125 d126 d127 d128 d129 d130 d131 d132 d133 d134 d135 d136 d137 d138 d139 
    d140 d141 d142 d143 d144 d145 d146 d147 d148 d149 d150 d151 d152 d153 d154 d155 d156 d157 d158 d159 
    d160 d161 d162 d163 d164 d165 d166 d167 d168 d169 d170 d171 d172 d173 d174 d175 d176 d177 d178 d179 
    d180 d181 d182 d183 d184 d185 d186 d187 d188 d189 d190 d191 d192 d193 d194 d195 d196 d197 d198 d199 
    d200 d201 d202 d203 d204 d205 d206 d207 d208 d209 d210 d211 d212 d213 d214 d215 d216 d217 d218 d219 
    d220 d221 d222 d223 d224 d225 d226 d227 d228 d229 d230 d231 d232 d233 d234 d235 d236 d237 d238 d239 
    d240 d241 d242 d243 d244 d245 d246 d247 d248 d249 d250 d251 d252 d253 d254 d255 d256 d257 d258 d259 
    d260 d261 d262 d263 d264 d265 d266 d267 d268 d269 d270 d271 d272 d273 d274 d275 d276 d277 d278 d279 
    d280 d281 d282 d283 d284 d285 d286 d287 d288 d289 d290 d291 d292 d293 d294 d295 d296 d297 d298 d299 
    d300 d301 d302 d303 d304 d305 d306 d307 d308 d309 d310 d311 d312 d313 d314 d315 d316 d317 d318 d319 
    d320 d321 d322 d323 d324 d325 d326 d327 d328 d329 d330 d331 d332 d333 d334 d335 d336 d337 d338 d339 
    d340 d341 d342 d343 d344 d345 d346 d347 d348 d349 d350 d351 d352 d353 d354 d355 d356 d357 d358 d359 
    d360 d361 d362 d363 d364 d365 d366 d367 d368 d369 d370 d371 d372 d373 d374 d375 d376 d377 d378 d379 
    d380 d381 d382 d383 d384 d385 d386 d387 d388 d389 d390 d391 d392 d393 d394 d395 d396 d397 d398 d399 
    d400 d401 d402 d403 d404 d405 d406 d407 d408 d409 d410 d411 d412 d413 d414 d415 d416 d417 d418 d419 
    d420 d421 d422 d423 d424 d425 d426 d427 d428 d429 d430 d431 d432 d433 d434 d435 d436 d437 d438 d439 
    d440 d441 d442 d443 d444 d445 d446 d447 d448 d449 d450 d451 d452 d453 d454 d455 d456 d457 d458 d459 
    d460 d461 d462 d463 d464 d465 d466 d467 d468 d469 d470 d471 d472 d473 d474 d475 d476 d477 d478 d479 
    d480 d481 d482 d483 d484 d485 d486 d487 d488 d489 d490 d491 d492 d493 d494 d495 d496 d497 d498 d499 
    d500 d501 d502 d503 d504 d505 d506 d507 d508 d509 d510 d511 d512 d513 d514 d515 d516 d517 d518 d519 
    d520 d521 d522 d523 d524 d525 d526 d527 d528 d529 d530 d531 d532 d533 d534 d535 d536 d537 d538 d539 
    d540 d541 d542 d543 d544 d545 d546 d547 d548 d549 d550 d551 d552 d553 d554 d555 d556 d557 d558 d559 
    d560 d561 d562 d563 d564 d565 d566 d567 d568 d569 d570 d571 d572 d573 d574 d575 d576 d577 d578 d579 
    d580 d581 d582 d583 d584 d585 d586 d587 d588 d589 d590 d591 d592 d593 d594 d595 d596 d597 d598 d599 
    d600 d601 d602 d603 d604 d605 d606 d607 d608 d609 d610 d611 d612 d613 d614 d615 d616 d617 d618 d619 
    d620 d621 d622 d623 d624 d625 d626 d627 d628 d629 d630 d631 d632 d633 d634 d635 d636 d637 d638 d639 
    d640 d641 d642 d643 d644 d645 d646 d647 d648 d649 d650 d651 d652 d653 d654 d655 d656 d657 d658 d659 
    d660 d661 d662 d663 d664 d665 d666 d667 d668 d669 d670 d671 d672 d673 d674 d675 d676 d677 d678 d679 
    d680 d681 d682 d683 d684 d685 d686 d687 d688 d689 d690 d691 d692 d693 d694 d695 d696 d697 d698 d699 
    d700 d701 d702 d703 d704 d705 d706 d707 d708 d709 d710 d711 d712 d713 d714 d715 d716 d717 d718 d719 
    d720 d721 d722 d723 d724 d725 d726 d727 d728 d729 d730 d731 d732 d733 d734 d735 d736 d737 d738 d739 
    d740 d741 d742 d743 d744 d745 d746 d747 d748 d749 d750 d751 d752 d753 d754 d755 d756 d757 d758 d759 
    d760 d761 d762 d763 d764 d765 d766 d767 d768 d769 d770 d771 d772 d773 d774 d775 d776 d777 d778 d779 
    d780 d781 d782 d783 d784 d785 d786 d787 d788 d789 d790 d791 d792 d793 d794 d795 d796 d797 d798 d799 
    d800 d801 d802 d803 d804 d805 d806 d807 d808 d809 d810 d811.
EXECUTE.

*Did it work?

DESCRIPTIVES VARIABLES=zipcode PerCapI PerCapitaIncome
  /STATISTICS=MEAN STDDEV MIN MAX.

*Case count and PerCapitaIncome N are fine, PerCapI drops by about 1k, but should also still be fine.
*Saving, augmenting merge count.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-10.sav'
  /COMPRESSED.

*Now, need to compute variables from these based on old TNC syntax (S3-L8220)

compute PCI1990=  PerCapI.
WRITE FORMATS  PCI1990 (F).
execute.

compute ChPCI290= PerCapitaIncome / PCI1990.
execute.

*Did it work?

DESCRIPTIVES VARIABLES=zipcode PerCapI PerCapitaIncome PCI1990 ChPCI290
  /STATISTICS=MEAN STDDEV MIN MAX.

*Looks good.  Final result, N for ChPCI290, is still just over 28k.  
*Saving in file, adding letter to indicate that computations have been done.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-10a.sav'
  /COMPRESSED.

***************************
*10/13
*Merging in CollProfLv90 from run2_1990.CUT.sav
*Opening latest main file.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-10a.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

SORT CASES BY zipcode(A).

*Opening source data file.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/Primary Data Sources/run2_1990.CUT.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

*Areakey is same as zipcode, so creating zipcode var for merge.

compute zipcode=AreaKey.
execute.

SORT CASES BY zipcode(A).

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/Primary Data Sources/run2_1990.CUT.sav'
  /COMPRESSED.

*Switching back manually to main dataset as active, and then the merge:

MATCH FILES /FILE=*
  /TABLE='DataSet2'
  /RENAME (AreaKey AreaName totpop25p90 = d0 d1 d2)
  /BY  zipcode
  /DROP= d0 d1 d2.
EXECUTE.

*Did it work?

DESCRIPTIVES VARIABLES=zipcode CollProfLv90
  /STATISTICS=MEAN STDDEV MIN MAX.

*No drop in case count, slight decrease in N of CollProfLv90 from source file, but looks OK.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-11.sav'
  /COMPRESSED.

***************************
*10/13/08
*Housing variables

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-11.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

SORT CASES BY zipcode(A).

GET
  FILE='/Users/erogers/Documents/Scenes/Data/Primary Data '+
    'Sources/EricMergeChkFiles2.Archive/Housing7.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

SORT CASES BY zipcode(A).

*Recomputing the ChGrRt2090 variable, to make sure it is what I think it is - should have N of 27781.

compute ChGrRt2090 = H063001/RntMed1990. 
EXECUTE.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/Primary Data '+
    'Sources/EricMergeChkFiles2.Archive/Housing7.sav'
  /COMPRESSED.

*Great, looks good.  Switching back to main data file as active, and the merge:

MATCH FILES /FILE=*
  /TABLE='DataSet2'
  /RENAME (AreaKey AreaName H061001 H062001 H062002 H062003 H062004 H062005 H062006 H062007 H062008 
    H062009 H062010 H062011 H062012 H062013 H062014 H062015 H062016 H062017 H062018 H062019 H062020 
    H062021 H062022 H062023 H062024 H064001 H065001 H065002 H065003 = d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 
    d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30)
  /BY  zipcode
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 
    d25 d26 d27 d28 d29 d30.
EXECUTE.

*Did it work?

DESCRIPTIVES VARIABLES=zipcode H063001 RntMed1990 ChGrRt2090
  /STATISTICS=MEAN STDDEV MIN MAX.

*Great, saving.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-12.sav'
  /COMPRESSED.

********************************
*10/16/08
*Merging in crime data

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-12.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

SORT CASES BY countcen(A).

GET
  FILE='/Users/erogers/Documents/Scenes/Data/Primary Data Sources/CCDB CountyCRime ONLY4.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

SORT CASES BY countcen(A).

*Switching to main dataset as active dataset, and then running the merge.  V21 is the var to merge in, then rename.

MATCH FILES /FILE=*
  /TABLE='DataSet2'
  /RENAME (TableB6.CountiesCrimeHousingandBuildingPermits V1 V2 V3 V4 V5 V6 = d0 d1 d2 d3 d4 d5 d6)
  /BY  countcen
  /DROP= d0 d1 d2 d3 d4 d5 d6.
EXECUTE.

*Did it work?

DESCRIPTIVES VARIABLES=zipcode countcen V21
  /STATISTICS=MEAN STDDEV MIN MAX.

*Looks great, renaming variable manually to old name (CrimeRate1999county) and saving.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-13.sav'
  /COMPRESSED.

**************************************
*10/17/08
*First, correcting an error made 9/23, line 547 above, I erroneously flippe the sign for the DDB factor score.
*What I was supposed to do was flip the sign for BIZZIP factor score.
*So, deleting the variable "DDB_FactorScore_Flip" manually in MergeB-13, and creating the new correct variable.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-13.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

*Deleted the incorrect DDB variable.  Now creating the bizzip variable.

compute BZ_FactorScore_Flip=BZ_FactorScore * (-1).
execute.

*Manually labeled, saved.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-13a.sav'
  /COMPRESSED.

********************
*10/17/08
*Now, see task #26 in Eric Rogers log #3:  creating a unified factor score from all data sources.

*Step 1:  Multiplying the dimensions from the difference sources together.

compute TradPerf_All=ZSpxMTtrad22nn_mean_impu*ZBZ01TradPerf_impu*ZYPTradPerf_impu.
compute SEPerf_All=ZSpxMTse22nn_mean_impu*ZBZ01SEPerf_impu*ZYPSEPerf_impu.
compute UtilPerf_All=ZSpxMTutil22nn_mean_impu*ZBZ01UtilPerf_impu*ZYPUtilPerf_impu.
compute CharPerf_All=ZSpxMTchar22nn_mean_impu*ZBZ01CharPerf_impu*ZYPCharPerf_impu.
compute NeighPerf_All=ZSpxMTneigh22nn_mean_impu*ZBZ01NeighPerf_impu*ZYPNeighPerf_impu.
compute FormalPerf_All=ZSpxMTform22nn_mean_impu*ZBZ01FormPerf_impu*ZYPFormPerf_impu.
compute ExhibPerf_All=ZSpxMTexhib22nn_mean_impu*ZBZ01ExhiPerf_impu*ZYPExhiPerf_impu.
compute GlamPerf_All=ZSpxMTglam22nn_mean_impu*ZBZ01GlamPerf_impu*ZYPGlamPerf_impu.
compute TransPerf_All=ZSpxMTtrans22nn_mean_impu*ZBZ01TransPerf_impu*ZYPTransPerf_impu.
compute RatioPerf_All=ZSpxMTratio22nn_mean_impu*ZBZ01RatPerf_impu*ZYPRatPerf_impu.
compute LocalPerf_All=ZSpxMTlocal22nn_mean_impu*ZBZ01LocalPerf_impu*ZYPLocalPerf_impu.
compute CorpoPerf_All=ZSpxMTcorpo22nn_mean_impu*ZBZ01CorpPerf_impu*ZYPCorpPerf_impu.
execute.

*Manually labeled these variables as "DIMENSION from all sources, multiplied".

*Now run factor analysis and save.  

FACTOR
  /VARIABLES TradPerf_All SEPerf_All UtilPerf_All CharPerf_All NeighPerf_All FormalPerf_All 
    ExhibPerf_All GlamPerf_All TransPerf_All RatioPerf_All LocalPerf_All CorpoPerf_All
  /MISSING LISTWISE 
  /ANALYSIS TradPerf_All SEPerf_All UtilPerf_All CharPerf_All NeighPerf_All FormalPerf_All 
    ExhibPerf_All GlamPerf_All TransPerf_All RatioPerf_All LocalPerf_All CorpoPerf_All
 /PRINT UNIVARIATE INITIAL EXTRACTION FSCORE
  /CRITERIA FACTORS(1) ITERATE(25)
  /EXTRACTION PC
  /ROTATION NOROTATE
  /SAVE REG(ALL)
  /METHOD=CORRELATION.

*Manually renamed the factor score as "factor1_mult", labeled "Factor 1 score from combined multiplied dimensions."

*Saved as MergeB-13a.sav.

*Now creating a factor score that just dumps ALL the dimensions together without first multiplying them.

FACTOR
  /VARIABLES ZSpxMTtrad22nn_mean_impu ZSpxMTse22nn_mean_impu ZSpxMTegal22nn_mean_impu 
    ZSpxMTutil22nn_mean_impu ZSpxMTchar22nn_mean_impu ZSpxMTneigh22nn_mean_impu 
    ZSpxMTform22nn_mean_impu ZSpxMTexhib22nn_mean_impu ZSpxMTglam22nn_mean_impu 
    ZSpxMTtrans22nn_mean_impu ZSpxMTratio22nn_mean_impu ZSpxMTlocal22nn_mean_impu 
    ZSpxMTstate22nn_mean_impu ZSpxMTcorpo22nn_mean_impu ZBZ01TradPerf_impu ZBZ01SEPerf_impu 
    ZBZ01UtilPerf_impu ZBZ01CharPerf_impu ZBZ01EgalPerf_impu ZBZ01NeighPerf_impu ZBZ01FormPerf_impu 
    ZBZ01ExhiPerf_impu ZBZ01GlamPerf_impu ZBZ01TransPerf_impu ZBZ01RatPerf_impu ZBZ01LocalPerf_impu 
    ZBZ01StatePerf_impu ZBZ01CorpPerf_impu ZBZ01EthnPerf_impu ZYPTradPerf_impu ZYPSEPerf_impu 
    ZYPUtilPerf_impu ZYPCharPerf_impu ZYPEgalPerf_impu ZYPNeighPerf_impu ZYPFormPerf_impu 
    ZYPExhiPerf_impu ZYPGlamPerf_impu ZYPTransPerf_impu ZYPRatPerf_impu ZYPLocalPerf_impu 
    ZYPStatePerf_impu ZYPCorpPerf_impu ZYPEthnPerf_impu
  /MISSING LISTWISE 
  /ANALYSIS ZSpxMTtrad22nn_mean_impu ZSpxMTse22nn_mean_impu ZSpxMTegal22nn_mean_impu 
    ZSpxMTutil22nn_mean_impu ZSpxMTchar22nn_mean_impu ZSpxMTneigh22nn_mean_impu 
    ZSpxMTform22nn_mean_impu ZSpxMTexhib22nn_mean_impu ZSpxMTglam22nn_mean_impu 
    ZSpxMTtrans22nn_mean_impu ZSpxMTratio22nn_mean_impu ZSpxMTlocal22nn_mean_impu 
    ZSpxMTstate22nn_mean_impu ZSpxMTcorpo22nn_mean_impu ZBZ01TradPerf_impu ZBZ01SEPerf_impu 
    ZBZ01UtilPerf_impu ZBZ01CharPerf_impu ZBZ01EgalPerf_impu ZBZ01NeighPerf_impu ZBZ01FormPerf_impu 
    ZBZ01ExhiPerf_impu ZBZ01GlamPerf_impu ZBZ01TransPerf_impu ZBZ01RatPerf_impu ZBZ01LocalPerf_impu 
    ZBZ01StatePerf_impu ZBZ01CorpPerf_impu ZBZ01EthnPerf_impu ZYPTradPerf_impu ZYPSEPerf_impu 
    ZYPUtilPerf_impu ZYPCharPerf_impu ZYPEgalPerf_impu ZYPNeighPerf_impu ZYPFormPerf_impu 
    ZYPExhiPerf_impu ZYPGlamPerf_impu ZYPTransPerf_impu ZYPRatPerf_impu ZYPLocalPerf_impu 
    ZYPStatePerf_impu ZYPCorpPerf_impu ZYPEthnPerf_impu
  /PRINT UNIVARIATE INITIAL EXTRACTION FSCORE
  /CRITERIA FACTORS(1) ITERATE(25)
  /EXTRACTION PC
  /ROTATION NOROTATE
  /SAVE REG(ALL)
  /METHOD=CORRELATION.

*Manually renaming the new variable as "factor1_all", labeled "Factor 1 score from combined dimensions from all sources."

*Saved again as MergeB-13a.sav.
*Manually assigned label to variable "PCI1990", as it is a core variable.  Resaved as MergeB-13a.sav.

***********************
*10/18/08
*Merging in ARTS JOBS data from Chris.

*First opening file from Chris and renaming key variable to match.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/Primary Data Sources/ArtsLQ9801Zip.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

*Manually renamed, now sort and save.

SORT CASES BY zipcode(A).

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/Primary Data Sources/ArtsLQ9801Zip.sav'
  /COMPRESSED.

*Opening the main data file, making it the active data set.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-13a.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

SORT CASES BY zipcode(A).

*And now the merge!

MATCH FILES /FILE=*
  /TABLE='DataSet1'
  /RENAME (PrimaryLast TotArtsEmpUS01 TotArtsEmpUS98 TotEmpUS01 TotEmpUS98 = d0 d1 d2 d3 d4)
  /BY  zipcode
  /DROP= d0 d1 d2 d3 d4.
EXECUTE.

*Manually labeled the variables.  Did the merge work?

DESCRIPTIVES VARIABLES=zipcode TotEmpZip98 TotArtsEmpZip98 ARTSLQ98 TotEmpZip01 TotArtsEmpZip01 
    ARTSLQ01
  /STATISTICS=MEAN STDDEV MIN MAX.

*The counts look good, so saving.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-14.sav'
  /COMPRESSED.

*Now, creating the needed CORE variable from these:

compute ARTSGOSLG=ln(ARTSLQ98).
execute.

*Looks fine, saving.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-14a.sav'
  /COMPRESSED.

********************
*10/21 Merging in 1994 jobs data from TNC

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-14a.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

SORT CASES BY zipcode(A).

GET
  FILE='/Users/erogers/Documents/Scenes/Data/Primary Data Sources/Agreg Total Jobs By zip in '+
    '1994.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

SORT CASES BY zipcode(A).

*Now, switching back to the primary data file as the active data set, and then the merge.

MATCH FILES /FILE=*
  /TABLE='DataSet2'
  /BY  zipcode.
EXECUTE.

*Did this work?

DESCRIPTIVES VARIABLES=zipcode total_emp_94_sum
  /STATISTICS=MEAN STDDEV MIN MAX.

*Yes, so saving.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-15.sav'
  /COMPRESSED.

*Now, creating the final missing core variable, replicating work done in TNC syntax 3 line ~7041.  

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-15.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

*Modifying the compute to use the 2001 employment data merged in above from Chris.

compute zipTemploy_ratio0194  = TotEmpZip01 /total_emp_94_sum.
execute.

compute LzipTemploy_ratio0194R =  LN (zipTemploy_ratio0194).
execute.

*Manually applying label as used in Merge20.

*Descriptives:

DESCRIPTIVES VARIABLES=TotEmpZip01 total_emp_94_sum zipTemploy_ratio0194 LzipTemploy_ratio0194R
  /STATISTICS=MEAN STDDEV MIN MAX.

*Looks decent, although the low N may be an issue again.  But saving, for now:

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-15a.sav'
  /COMPRESSED.

***********
*10/23/08
*Creating imputed and standardized county-level BZ and YP performance scores.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-15a.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

*First, creating the new variables to do the imputation step.

compute YPTradPerf_cty_impu=YPTradPerf_cty.
compute YPSEPerf_cty_impu=YPSEPerf_cty.
compute YPUtilPerf_cty_impu=YPUtilPerf_cty.
compute YPCharPerf_cty_impu=YPCharPerf_cty.
compute YPEgalPerf_cty_impu=YPEgalPerf_cty.
compute YPNeighPerf_cty_impu=YPNeighPerf_cty.
compute YPFormPerf_cty_impu=YPFormPerf_cty.
compute YPExhiPerf_cty_impu=YPExhiPerf_cty.
compute YPGlamPerf_cty_impu=YPGlamPerf_cty.
compute YPTransPerf_cty_impu=YPTransPerf_cty.
compute YPRatPerf_cty_impu=YPRatPerf_cty.
compute YPLocalPerf_cty_impu=YPLocalPerf_cty.
compute YPStatePerf_cty_impu=YPStatePerf_cty.
compute YPCorpPerf_cty_impu=YPCorpPerf_cty.
compute YPEthnPerf_cty_impu=YPEthnPerf_cty.
compute BZ01TradPerf_cty_impu=BZ01TradPerf_cty.
compute BZ01SEPerf_cty_impu=BZ01SEPerf_cty.
compute BZ01UtilPerf_cty_impu=BZ01UtilPerf_cty.
compute BZ01CharPerf_cty_impu=BZ01CharPerf_cty.
compute BZ01EgalPerf_cty_impu=BZ01EgalPerf_cty.
compute BZ01NeighPerf_cty_impu=BZ01NeighPerf_cty.
compute BZ01FormPerf_cty_impu=BZ01FormPerf_cty.
compute BZ01ExhiPerf_cty_impu=BZ01ExhiPerf_cty.
compute BZ01GlamPerf_cty_impu=BZ01GlamPerf_cty.
compute BZ01TransPerf_cty_impu=BZ01TransPerf_cty.
compute BZ01RatPerf_cty_impu=BZ01RatPerf_cty.
compute BZ01LocalPerf_cty_impu=BZ01LocalPerf_cty.
compute BZ01StatePerf_cty_impu=BZ01StatePerf_cty.
compute BZ01CorpPerf_cty_impu=BZ01CorpPerf_cty.
compute BZ01EthnPerf_cty_impu=BZ01EthnPerf_cty.
execute.

var lab
YPTradPerf_cty_impu 'Traditionalism performance score from Yellow Pages data, county (i2.99)'
YPSEPerf_cty_impu 'Self-Expression performance score from Yellow Pages data, county (i2.99)'
YPUtilPerf_cty_impu 'Utilitarianism performance score from Yellow Pages data, county (i2.99)'
YPCharPerf_cty_impu 'Charismatic performance score from Yellow Pages data, county (i2.99)'
YPEgalPerf_cty_impu 'Egalitarian performance score from Yellow Pages data, county (i2.99)'
YPNeighPerf_cty_impu 'Neighborliness performance score from Yellow Pages data, county (i2.99)'
YPFormPerf_cty_impu 'Formality performance score from Yellow Pages data, county (i2.99)'
YPExhiPerf_cty_impu 'Exhibitionism performance score from Yellow Pages data, county (i2.99)'
YPGlamPerf_cty_impu 'Glamour performance score from Yellow Pages data, county (i2.99)'
YPTransPerf_cty_impu 'Transgressive performance score from Yellow Pages data, county (i2.99)'
YPRatPerf_cty_impu 'Rational performance score from Yellow Pages data, county (i2.99)'
YPLocalPerf_cty_impu 'Localism performance score from Yellow Pages data, county (i2.99)'
YPStatePerf_cty_impu 'Statism performance score from Yellow Pages data, county (i2.99)'
YPCorpPerf_cty_impu 'Corporatism performance score from Yellow Pages data, county (i2.99)'
YPEthnPerf_cty_impu 'Ethnicity performance score from Yellow Pages data, county (i2.99)'
BZ01TradPerf_cty_impu 'Traditionalism performance score from 2001 Bizzip data, county (i2.99)'
BZ01SEPerf_cty_impu 'Self-Expression performance score from 2001 Bizzip data, county (i2.99)'
BZ01UtilPerf_cty_impu 'Utilitarianism performance score from 2001 Bizzip data, county (i2.99)'
BZ01CharPerf_cty_impu 'Charismatic performance score from 2001 Bizzip data, county (i2.99)'
BZ01EgalPerf_cty_impu 'Egalitarian performance score from 2001 Bizzip data, county (i2.99)'
BZ01NeighPerf_cty_impu 'Egalitarian performance score from 2001 Bizzip data, county (i2.99)'
BZ01FormPerf_cty_impu 'Formality performance score from 2001 Bizzip data, county (i2.99)'
BZ01ExhiPerf_cty_impu 'Exhibitionism performance score from 2001 Bizzip data, county (i2.99)'
BZ01GlamPerf_cty_impu 'Glamour performance score from 2001 Bizzip data, county (i2.99)'
BZ01TransPerf_cty_impu 'Transgressive performance score from 2001 Bizzip data, county (i2.99)'
BZ01RatPerf_cty_impu 'Rational performance score from 2001 Bizzip data, county (i2.99)'
BZ01LocalPerf_cty_impu 'Localism performance score from 2001 Bizzip data, county (i2.99)'
BZ01StatePerf_cty_impu 'Statism performance score from 2001 Bizzip data, county (i2.99)'
BZ01CorpPerf_cty_impu 'Corporatism performance score from 2001 Bizzip data, county (i2.99)'
BZ01EthnPerf_cty_impu 'Ethnicity performance score from 2001 Bizzip data, county (i2.99)'
execute.

*And now, the actual imputation step:

recode YPTradPerf_cty_impu TO BZ01EthnPerf_cty_impu (sysms=2.99).
execute.

*Looks good, now the next step is to create Z-scores for these.

DESCRIPTIVES VARIABLES=YPTradPerf_cty_impu YPSEPerf_cty_impu YPUtilPerf_cty_impu 
    YPCharPerf_cty_impu YPEgalPerf_cty_impu YPNeighPerf_cty_impu YPFormPerf_cty_impu 
    YPExhiPerf_cty_impu YPGlamPerf_cty_impu YPTransPerf_cty_impu YPRatPerf_cty_impu 
    YPLocalPerf_cty_impu YPStatePerf_cty_impu YPCorpPerf_cty_impu YPEthnPerf_cty_impu 
    BZ01TradPerf_cty_impu BZ01SEPerf_cty_impu BZ01UtilPerf_cty_impu BZ01CharPerf_cty_impu 
    BZ01EgalPerf_cty_impu BZ01NeighPerf_cty_impu BZ01FormPerf_cty_impu BZ01ExhiPerf_cty_impu 
    BZ01GlamPerf_cty_impu BZ01TransPerf_cty_impu BZ01RatPerf_cty_impu BZ01LocalPerf_cty_impu 
    BZ01StatePerf_cty_impu BZ01CorpPerf_cty_impu BZ01EthnPerf_cty_impu
  /SAVE
  /STATISTICS=MEAN STDDEV MIN MAX.

*OK, this is done.  Saving.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-15b.sav'
  /COMPRESSED.

*******************************
*10/24/08
*Got bizzip arts and tech job data from Sam.  Now to merge it in.  But first, need to remove some of what I got from Chris.
*See Eric Rogers log file #3, entry #29 for this date for more discussion of what I'm doing here and why.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-15b.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

*The following variables, all merged in from Chris or computed from his vars previously, are now being REMOVED manually from this file, to be replaced.
TotEmpZip98
TotArtsEmpZip98
ARTSLQ98
TotEmpZip01
TotArtsEmpZip01
ARTSLQ01
ARTSGOSLG
zipTemploy_ratio0194
LzipTemploy_ratio0194R

*OK, now sort this by zip.

SORT CASES BY zipcode(A).

*Great, now I'm good to start merging variables from Sam into this file.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/SHB bizzip indices syntax and data/artsup1_zipagg.sav'.    
DATASET NAME DataSet14 WINDOW=FRONT.

*Renaming "zip" to "zipcode", sorting on it, and resaving.

SORT CASES BY zipcode(A).

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/SHB bizzip indices syntax and '+
    'data/artsup1_zipagg.sav'
  /COMPRESSED.

*Switching back to main dataset as active, and now the merge:

MATCH FILES /FILE=*
  /TABLE='DataSet14'
  /RENAME (ARTsup1LQ01sysmis ARTsup1LQ98sysmis D_R employ_change employ_ratio int1000_01 int1000_98 
    int100_249_01 int100_249_98 int10_19_01 int10_19_98 int1_4_01 int1_4_98 int20_49_01 int20_49_98 
    int250_499_01 int250_499_98 int500_999_01 int500_999_98 int50_99_01 int50_99_98 int5_9_01 int5_9_98 
    merge_id merge_int pnac PrimaryLast sector tot_estb tot_estb_98 total_emp_01 Total_emp_01_sum 
    total_emp_98 Total_emp_98_sum total_zipemp_01_sum_ total_zipemp_98_sum_ USA = d0 d1 d2 d3 d4 d5 d6 
    d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31 
    d32 d33 d34 d35 d36)
  /BY  zipcode
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 
    d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36.
EXECUTE.

*Did this work OK?

DESCRIPTIVES VARIABLES=zipcode ARTsup1totalemp98 ARTsup1zipemp98 ARTsup1totalemp01 ARTsup1zipemp01 
    ARTSUP1LQ98 ARTSUP1LQ01 ARTsup1LG98 ARTsup1LG01
  /STATISTICS=MEAN STDDEV MIN MAX.

*Yes, worked.  Now on to the next one.  Not saving intermediate files, as that would explode the size of my data archive very quickly.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/SHB bizzip indices syntax and data/artgos_zipagg.sav'.
DATASET NAME DataSet16 WINDOW=FRONT.

*Renaming "zip" to "zipcode", sorting on it, and resaving.

SORT CASES BY zipcode(A).

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/SHB bizzip indices syntax and '+
    'data/artgos_zipagg.sav'
  /COMPRESSED.

*Now switching back to main dataset as active, and then the merge:

MATCH FILES /FILE=*
  /TABLE='DataSet16'
  /RENAME (artGOSLQ01sysmis artGOSLQ98sysmis D_R employ_change employ_ratio int1000_01 int1000_98 
    int100_249_01 int100_249_98 int10_19_01 int10_19_98 int1_4_01 int1_4_98 int20_49_01 int20_49_98 
    int250_499_01 int250_499_98 int500_999_01 int500_999_98 int50_99_01 int50_99_98 int5_9_01 int5_9_98 
    merge_id merge_int pnac PrimaryLast sector tot_estb tot_estb_98 total_emp_01 Total_emp_01_sum 
    total_emp_98 Total_emp_98_sum total_zipemp_01_sum_ total_zipemp_98_sum_ USA = d0 d1 d2 d3 d4 d5 d6 
    d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31 
    d32 d33 d34 d35 d36)
  /BY  zipcode
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 
    d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36.
EXECUTE.

*Did it work?

DESCRIPTIVES VARIABLES=zipcode ARTGOStotalemp98 ARTGOSzipemp98 ARTGOStotalemp01 ARTGOSzipemp01 
    artgosLQ98 artgosLQ01 ARTGOSLG98 ARTGOSLG01
  /STATISTICS=MEAN STDDEV MIN MAX.

*Yep, looks good, now moving on to the next file.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/SHB bizzip indices syntax and data/rdjobs_zipagg.sav'.
DATASET NAME DataSet17 WINDOW=FRONT.

*Renaming "zip" to "zipcode", sorting on it, and resaving.

SORT CASES BY zipcode(A).

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/SHB bizzip indices syntax and '+
    'data/rdjobs_zipagg.sav'
  /COMPRESSED.

*Switching back to main datafile as active, and the merge:

MATCH FILES /FILE=*
  /TABLE='DataSet17'
  /RENAME (D_R employ_change employ_ratio int1000_01 int1000_98 int100_249_01 int100_249_98 
    int10_19_01 int10_19_98 int1_4_01 int1_4_98 int20_49_01 int20_49_98 int250_499_01 int250_499_98 
    int500_999_01 int500_999_98 int50_99_01 int50_99_98 int5_9_01 int5_9_98 merge_id merge_int pnac 
    PrimaryLast rdjobsLQ01sysmis rdjobsLQ98sysmis sector tot_estb tot_estb_98 total_emp_01 
    Total_emp_01_sum total_emp_98 Total_emp_98_sum total_zipemp_01_sum_ total_zipemp_98_sum_ USA = d0 
    d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 
    d28 d29 d30 d31 d32 d33 d34 d35 d36)
  /BY  zipcode
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 
    d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36.
EXECUTE.

*Did it work?

DESCRIPTIVES VARIABLES=zipcode RDJOBStotalemp98 RDJOBSzipemp98 RDJOBStotalemp01 RDJOBSzipemp01 
    RDJOBSLQ98 RDJOBSLQ01 rdjobsLG98 rdjobsLG01
  /STATISTICS=MEAN STDDEV MIN MAX.

*Yes, moving on to next:

GET
  FILE='/Users/erogers/Documents/Scenes/Data/SHB bizzip indices syntax and '+
    'data/techbroad_zipagg.sav'.
DATASET NAME DataSet18 WINDOW=FRONT.

*Renaming "zip" to "zipcode", sorting on it, and resaving.

SORT CASES BY zipcode(A).

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/SHB bizzip indices syntax and '+
    'data/techbroad_zipagg.sav'
  /COMPRESSED.

*Switching to main set as active, and then the merge:

MATCH FILES /FILE=*
  /TABLE='DataSet18'
  /RENAME (D_R employ_change employ_ratio int1000_01 int1000_98 int100_249_01 int100_249_98 
    int10_19_01 int10_19_98 int1_4_01 int1_4_98 int20_49_01 int20_49_98 int250_499_01 int250_499_98 
    int500_999_01 int500_999_98 int50_99_01 int50_99_98 int5_9_01 int5_9_98 merge_id merge_int pnac 
    PrimaryLast sector techbroadLQ01sysmis techbroadLQ98sysmis tot_estb tot_estb_98 total_emp_01 
    Total_emp_01_sum total_emp_98 Total_emp_98_sum total_zipemp_01_sum_ total_zipemp_98_sum_ USA = d0 
    d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 
    d28 d29 d30 d31 d32 d33 d34 d35 d36)
  /BY  zipcode
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 
    d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36.
EXECUTE.

*Did it work?

DESCRIPTIVES VARIABLES=zipcode techbroadtotalemp98 techbroadzipemp98 techbroadtotalemp01 
    techbroadzipemp01 techbroadLQ98 techbroadLQ01 techbroadLG98 techbroadLG01
  /STATISTICS=MEAN STDDEV MIN MAX.

*Yep, moving to next file.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/SHB bizzip indices syntax and '+
    'data/technarrow_zipagg.sav'.
DATASET NAME DataSet19 WINDOW=FRONT.

*Renaming "zip" to "zipcode", sorting on it, and resaving.

SORT CASES BY zipcode(A).

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/SHB bizzip indices syntax and '+
    'data/technarrow_zipagg.sav'
  /COMPRESSED.

*Switching back to main set as active, and then the merge:

MATCH FILES /FILE=*
  /TABLE='DataSet19'
  /RENAME (D_R employ_change employ_ratio int1000_01 int1000_98 int100_249_01 int100_249_98 
    int10_19_01 int10_19_98 int1_4_01 int1_4_98 int20_49_01 int20_49_98 int250_499_01 int250_499_98 
    int500_999_01 int500_999_98 int50_99_01 int50_99_98 int5_9_01 int5_9_98 merge_id merge_int pnac 
    PrimaryLast sector technarrowLQ01sysmis technarrowLQ98sysmis tot_estb tot_estb_98 total_emp_01 
    Total_emp_01_sum total_emp_98 Total_emp_98_sum total_zipemp_01_sum_ total_zipemp_98_sum_ USA = d0 
    d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 
    d28 d29 d30 d31 d32 d33 d34 d35 d36)
  /BY  zipcode
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 
    d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36.
EXECUTE.

*Did it work?

DESCRIPTIVES VARIABLES=zipcode technarrowtotalemp98 technarrowzipemp98 technarrowtotalemp01 
    technarrowzipemp01 technarrowLQ98 technarrowLQ01 technarrowLG98 technarrowLG01
  /STATISTICS=MEAN STDDEV MIN MAX.

*Great, now saving.  Merged in 5 files, so augmenting merge counter in name by 5:

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-20.sav'
  /COMPRESSED.

*********************
*10/24/08
*Now, trying to get the total zip employment figures for 1998 and 2001 out of the complete bizzip file.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/Primary Data '+
    'Sources/BIZZIP/TH30Nov06BIZZIP_Employment_1998-2001.SORTED by zip.sav'.
DATASET NAME DataSet20 WINDOW=FRONT.

AGGREGATE
  /OUTFILE='/Users/erogers/Documents/Scenes/Data/Primary Data '+
    'Sources/BIZZIP/bizzip-employment-sums.sav'
  /BREAK=zip
  /total_emp_98_sum=SUM(total_emp_98) 
  /total_emp_01_sum=SUM(total_emp_01).

*Did this work?

GET
  FILE='/Users/erogers/Documents/Scenes/Data/Primary Data '+
    'Sources/BIZZIP/bizzip-employment-sums.sav'.
DATASET NAME DataSet21 WINDOW=FRONT.

DESCRIPTIVES VARIABLES=zip total_emp_98_sum total_emp_01_sum
  /STATISTICS=MEAN STDDEV MIN MAX.

*Looks great!  Just manually deleting the garbage case with no zip code, resaving.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/Primary Data '+
    'Sources/BIZZIP/bizzip-employment-sums.sav'
  /COMPRESSED.

*Renaming "zip" to "zipcode", sorting by it, and resaving.

SORT CASES BY zipcode(A).

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/Primary Data '+
    'Sources/BIZZIP/bizzip-employment-sums.sav'
  /COMPRESSED.

*Great, now switching back to the main dataset as active, and merging!

MATCH FILES /FILE=*
  /TABLE='DataSet21'
  /BY  zipcode.
EXECUTE.

*Did this work?

DESCRIPTIVES VARIABLES=zipcode total_emp_98_sum total_emp_01_sum
  /STATISTICS=MEAN STDDEV MIN MAX.

*Yes, saving as new file.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-21.sav'
  /COMPRESSED.

****************************
*10/24/08
*Now, I have some computations to do!  Need to recreate LzipTemploy_ratio0194R

compute zipTemploy_ratio0194  = total_emp_01_sum /total_emp_94_sum.
execute.

compute LzipTemploy_ratio0194R =  LN (zipTemploy_ratio0194).
execute.

*Manually applying label as used in Merge20.

*Descriptives:

DESCRIPTIVES VARIABLES=total_emp_01_sum total_emp_94_sum zipTemploy_ratio0194 LzipTemploy_ratio0194R
  /STATISTICS=MEAN STDDEV MIN MAX.

*Fantastic!  Saving as new file.

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-21a.sav'
  /COMPRESSED.

************************
*10/28/08
*Merging in the new ARTGO variable from Sam, as corrected.

*Opening the latest main file.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-21a.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

SORT CASES BY zipcode(A).

*Now opening file from Sam, renaming "zip" to "zipcoding", sortin on it, and resaving it.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/SHB bizzip indices syntax and data/artgo_zipagg.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

SORT CASES BY zipcode(A).

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/SHB bizzip indices syntax and '+
    'data/artgo_zipagg.sav'
  /COMPRESSED.

*Now switching back to main file as active, and then the merge!

MATCH FILES /FILE=*
  /TABLE='DataSet2'
  /RENAME (ARTGOLQ01sysmis ARTGOLQ98sysmis D_R employ_change employ_ratio int1000_01 int1000_98 
    int100_249_01 int100_249_98 int10_19_01 int10_19_98 int1_4_01 int1_4_98 int20_49_01 int20_49_98 
    int250_499_01 int250_499_98 int500_999_01 int500_999_98 int50_99_01 int50_99_98 int5_9_01 int5_9_98 
    merge_id merge_int pnac PrimaryLast sector tot_estb tot_estb_98 total_emp_01 Total_emp_01_sum 
    total_emp_98 Total_emp_98_sum total_zipemp_01_sum_ total_zipemp_98_sum_ USA = d0 d1 d2 d3 d4 d5 d6 
    d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31 
    d32 d33 d34 d35 d36)
  /BY  zipcode
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 
    d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36.
EXECUTE.

*Did it work?

DESCRIPTIVES VARIABLES=zipcode ARTGOtotalemp98 ARTGOzipemp98 ARTGOtotalemp01 ARTGOzipemp01 
    ARTGOLQ98 ARTGOLQ01 ARTGOLG98 ARTGOLG01
  /STATISTICS=MEAN STDDEV MIN MAX.

*Great, saving!

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-22.sav'
  /COMPRESSED.


**************************************************
*11/23/08
*Merging in restaurant diversity, as computed by Chris Graziul

*Open the latest data file.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-22.sav'.
DATASET NAME DataSet1 WINDOW=FRONT.

SORT CASES BY zipcode(A).

*Opening source data file.

GET
  FILE='/Users/erogers/Documents/Scenes/Data/Restaurant Diversity/RestDiversity.sav'.
DATASET NAME DataSet2 WINDOW=FRONT.

*Manually renamed "zip" to "zipcode".

SORT CASES BY zipcode(A).

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/Restaurant Diversity/RestDiversity.sav'
  /COMPRESSED.

*Switch back to main file as active, and then the merge!

MATCH FILES /FILE=*
  /TABLE='DataSet2'
  /RENAME (NumNeedToChange NumTypes TotRestaurants = d0 d1 d2)
  /BY  zipcode
  /DROP= d0 d1 d2.
EXECUTE.

*Did it work?

DESCRIPTIVES VARIABLES=zipcode RestUndiversity
  /STATISTICS=MEAN STDDEV MIN MAX.

*Saving new data file:

SAVE OUTFILE='/Users/erogers/Documents/Scenes/Data/CleanMerge/MergeB-23.sav'
  /COMPRESSED.